@@ -11,92 +11,80 @@ from ..ppg import ppg_analyze
 from ..rsp import rsp_analyze
 
 
-def bio_analyze(data, sampling_rate=1000, method="auto", window_lengths='constant', subepoch_rate=[None, None]):
-    """Automated analysis of bio signals.
+def bio_analyze(data, sampling_rate=1000, method="auto", window_lengths="constant"):
+    """**Automated analysis of physiological signals**
 
-    Wrapper for other bio analyze functions of
-    electrocardiography signals (ECG), respiration signals (RSP), electrodermal activity (EDA),
-    electromyography signals (EMG) and electrooculography signals (EOG).
+    Wrapper for other bio analyze functions of electrocardiography signals (ECG), respiration
+    signals (RSP), electrodermal activity (EDA), electromyography signals (EMG) and
+    electrooculography signals (EOG).
 
     Parameters
     ----------
     data : DataFrame
         The DataFrame containing all the processed signals, typically
-        produced by `bio_process()`, `ecg_process()`, `rsp_process()`,
-        `eda_process()`, `emg_process()` or `eog_process()`.
+        produced by :func:`.bio_process`, :func:`.ecg_process`, :func:`.rsp_process`,
+        :func:`.eda_process`, :func:`.emg_process` or :func:`.eog_process`. Can also be an
+        epochs object.
     sampling_rate : int
         The sampling frequency of the signals (in Hz, i.e., samples/second).
         Defaults to 1000.
     method : str
-        Can be one of 'event-related' for event-related analysis on epochs,
-        or 'interval-related' for analysis on longer periods of data. Defaults
-        to 'auto' where the right method will be chosen based on the
-        mean duration of the data ('event-related' for duration under 10s).
+        Can be one of ``"event-related"`` for event-related analysis on epochs,
+        or ``"interval-related"`` for analysis on longer periods of data. Defaults
+        to ``auto`` where the right method will be chosen based on the
+        mean duration of the data (event-related for duration under 10s).
     window_lengths : dict
-        Defaults to 'constant'. Add a dictionary of epoch start and end times for different
-        types of signals e.g., window_lengths = {'ECG': [0.5, 1.5], 'EDA': [0.5, 3.5]}
-    subepoch_rate : list, dict
-        For event-related analysis,, a smaller "sub-epoch" within the epoch of an event can be specified.
-        The ECG and RSP rate-related features of this "sub-epoch" (e.g., ECG_Rate, ECG_Rate_Max),
-        relative to the baseline (where applicable), will be computed, e.g., subepoch_rate = [1, 3]
-        or subepoch_rate = {'ECG_Rate' = [1, 2], 'RSP_Rate' = [1.5, None]} if different sub-epoch length
-        for different signal is desired. Defaults to [None, None]. The first value of the list specifies
-        the start of the sub-epoch and the second specifies the end of the sub-epoch (in seconds),
+        If ``constant`` (default), will use the full epoch for all the signals. Can also
+        be a dictionary with the epoch start and end times for different
+        types of signals, e.g., ``window_lengths = {"ECG": [0.5, 1.5], "EDA": [0.5, 3.5]}``
 
     Returns
     ----------
     DataFrame
-        DataFrame of the analyzed bio features. See docstrings of `ecg_analyze()`,
-        `rsp_analyze()`, `eda_analyze()`, `emg_analyze()` and `eog_analyze()` for more details.
-        Also returns Respiratory Sinus Arrhythmia features produced by
-        `hrv_rsa()` if interval-related analysis is carried out.
+        DataFrame of the analyzed bio features. See docstrings of :func:`.ecg_analyze()`,
+        :func:`.rsp_analyze()`, :func:`.eda_analyze()`, :func:`.emg_analyze()` and
+        :func:`.eog_analyze()` for more details. Also returns Respiratory Sinus Arrhythmia features
+        produced by :func:`.hrv_rsa()` if interval-related analysis is carried out.
 
     See Also
     ----------
-    ecg_analyze, rsp_analyze, eda_analyze, emg_analyze, eog_analyze
+    .ecg_analyze, .rsp_analyze, .eda_analyze, .emg_analyze, .eog_analyze
 
     Examples
     ----------
-    >>> import neurokit2 as nk
-    >>>
-    >>> # Example 1: Event-related analysis
-    >>> # Download data
-    >>> data = nk.data("bio_eventrelated_100hz")
-    >>>
-    >>> # Process the data
-    >>> df, info = nk.bio_process(ecg=data["ECG"], rsp=data["RSP"], eda=data["EDA"],
-    ...                           keep=data["Photosensor"], sampling_rate=100)
-    >>>
-    >>> # Build epochs
-    >>> events = nk.events_find(data["Photosensor"], threshold_keep='below',
-    ...                         event_conditions=["Negative", "Neutral",
-    ...                                           "Neutral", "Negative"])
-    >>> epochs = nk.epochs_create(df, events, sampling_rate=100, epochs_start=-0.1,
-    ...                           epochs_end=1.9)
-    >>>
-    >>> # Analyze
-    >>> nk.bio_analyze(epochs, sampling_rate=100) #doctest: +ELLIPSIS
-      Label Condition  Event_Onset  ...         RSA_Gates
-    1     1  Negative          ...  ...           ...
-    2     2   Neutral          ...  ...           ...
-    3     3   Neutral          ...  ...           ...
-    4     4  Negative          ...  ...           ...
+    .. ipython:: python
 
-    ...
-    >>>
-    >>> # Example 2: Interval-related analysis
-    >>> # Download data
-    >>> data = nk.data("bio_resting_5min_100hz")
-    >>>
-    >>> # Process the data
-    >>> df, info = nk.bio_process(ecg=data["ECG"], rsp=data["RSP"], ppg=data["PPG"], sampling_rate=100)
-    >>>
-    >>> # Analyze
-    >>> nk.bio_analyze(df, sampling_rate=100) #doctest: +ELLIPSIS
-       ECG_Rate_Mean  HRV_MeanNN  ...  RSA_Gates_Mean_log  RSA_Gates_SD
-    0            ...        ...  ...            ...               ...
+      import neurokit2 as nk
+
+      # Example 1: Event-related analysis ==================================================
+      # Download data
+      data = nk.data("bio_eventrelated_100hz")
+
+      # Process the data
+      df, info = nk.bio_process(ecg=data["ECG"], rsp=data["RSP"], eda=data["EDA"],
+                               keep=data["Photosensor"], sampling_rate=100)
+
+      # Build epochs around photosensor-marked events
+      events = nk.events_find(data["Photosensor"], threshold_keep="below",
+                             event_conditions=["Negative", "Neutral",
+                                               "Neutral", "Negative"])
+      epochs = nk.epochs_create(df, events, sampling_rate=100, epochs_start=-0.1,
+                               epochs_end=1.9)
+
+      # Analyze
+      nk.bio_analyze(epochs, sampling_rate=100)
+
+
+      # Example 2: Interval-related analysis =================================================
+      # Download data
+      data = nk.data("bio_resting_5min_100hz")
+
+      # Process the data
+      df, info = nk.bio_process(ecg=data["ECG"], rsp=data["RSP"], ppg=data["PPG"], sampling_rate=100)
+
+      # Analyze
+      nk.bio_analyze(df, sampling_rate=100)
 
-    [1 rows x 184 columns]
     """
     features = pd.DataFrame()
     method = method.lower()
@@ -129,31 +117,31 @@ def bio_analyze(data, sampling_rate=1000, method="auto", window_lengths='constan
     # ECG
     if len(ecg_cols) != 0:
         ecg_data = data.copy()
-        if window_lengths != 'constant':
-            if 'ECG' in window_lengths.keys():  # only for epochs
-                ecg_data = _bio_analyze_slicewindow(ecg_data, window_lengths, signal='ECG')
+        if window_lengths != "constant":
+            if "ECG" in window_lengths.keys():  # only for epochs
+                ecg_data = _bio_analyze_slicewindow(ecg_data, window_lengths, signal="ECG")
 
-        ecg_analyzed = ecg_analyze(ecg_data, sampling_rate=sampling_rate, method=method, subepoch_rate=subepoch_rate)
+        ecg_analyzed = ecg_analyze(ecg_data, sampling_rate=sampling_rate, method=method)
         features = pd.concat([features, ecg_analyzed], axis=1, sort=False)
 
     # RSP
     if len(rsp_cols) != 0:
         rsp_data = data.copy()
 
-        if window_lengths != 'constant':
-            if 'RSP' in window_lengths.keys():  # only for epochs
-                rsp_data = _bio_analyze_slicewindow(rsp_data, window_lengths, signal='RSP')
+        if window_lengths != "constant":
+            if "RSP" in window_lengths.keys():  # only for epochs
+                rsp_data = _bio_analyze_slicewindow(rsp_data, window_lengths, signal="RSP")
 
-        rsp_analyzed = rsp_analyze(rsp_data, sampling_rate=sampling_rate, method=method, subepoch_rate=subepoch_rate)
+        rsp_analyzed = rsp_analyze(rsp_data, sampling_rate=sampling_rate, method=method)
         features = pd.concat([features, rsp_analyzed], axis=1, sort=False)
 
     # EDA
     if len(eda_cols) != 0:
         eda_data = data.copy()
 
-        if window_lengths != 'constant':
-            if 'EDA' in window_lengths.keys():  # only for epochs
-                eda_data = _bio_analyze_slicewindow(eda_data, window_lengths, signal='EDA')
+        if window_lengths != "constant":
+            if "EDA" in window_lengths.keys():  # only for epochs
+                eda_data = _bio_analyze_slicewindow(eda_data, window_lengths, signal="EDA")
 
         eda_analyzed = eda_analyze(eda_data, sampling_rate=sampling_rate, method=method)
         features = pd.concat([features, eda_analyzed], axis=1, sort=False)
@@ -162,20 +150,20 @@ def bio_analyze(data, sampling_rate=1000, method="auto", window_lengths='constan
     if len(emg_cols) != 0:
         emg_data = data.copy()
 
-        if window_lengths != 'constant':
-            if 'EMG' in window_lengths.keys():  # only for epochs
-                emg_data = _bio_analyze_slicewindow(emg_data, window_lengths, signal='EMG')
+        if window_lengths != "constant":
+            if "EMG" in window_lengths.keys():  # only for epochs
+                emg_data = _bio_analyze_slicewindow(emg_data, window_lengths, signal="EMG")
 
         emg_analyzed = emg_analyze(emg_data, sampling_rate=sampling_rate, method=method)
         features = pd.concat([features, emg_analyzed], axis=1, sort=False)
 
-    # EMG
+    # PPG
     if len(ppg_cols) != 0:
         ppg_data = data.copy()
 
-        if window_lengths != 'constant':
-            if 'PPG' in window_lengths.keys():  # only for epochs
-                ppg_data = _bio_analyze_slicewindow(ppg_data, window_lengths, signal='PPG')
+        if window_lengths != "constant":
+            if "PPG" in window_lengths.keys():  # only for epochs
+                ppg_data = _bio_analyze_slicewindow(ppg_data, window_lengths, signal="PPG")
 
         ppg_analyzed = ppg_analyze(ppg_data, sampling_rate=sampling_rate, method=method)
         features = pd.concat([features, ppg_analyzed], axis=1, sort=False)
@@ -184,31 +172,33 @@ def bio_analyze(data, sampling_rate=1000, method="auto", window_lengths='constan
     if len(eog_cols) != 0:
         eog_data = data.copy()
 
-        if window_lengths != 'constant':
-            if 'EOG' in window_lengths.keys():  # only for epochs
-                eog_data = _bio_analyze_slicewindow(eog_data, window_lengths, signal='EOG')
+        if window_lengths != "constant":
+            if "EOG" in window_lengths.keys():  # only for epochs
+                eog_data = _bio_analyze_slicewindow(eog_data, window_lengths, signal="EOG")
 
         eog_analyzed = eog_analyze(eog_data, sampling_rate=sampling_rate, method=method)
         features = pd.concat([features, eog_analyzed], axis=1, sort=False)
 
     # RSA
     if len(ecg_rate_col + rsp_phase_col) >= 3:
+        if method == "auto":
+            duration = _bio_analyze_findduration(data, sampling_rate=sampling_rate)
+            if duration >= 10:
+                method = "interval"
+            else:
+                method = "event"
 
         # Event-related
         if method in ["event-related", "event", "epoch"]:
-            rsa = _bio_analyze_rsa_event(data)
+            rsa = _bio_analyze_rsa_event(data.copy())
 
         # Interval-related
         elif method in ["interval-related", "interval", "resting-state"]:
-            rsa = _bio_analyze_rsa_interval(data, sampling_rate=sampling_rate)
+            rsa = _bio_analyze_rsa_interval(data.copy(), sampling_rate=sampling_rate)
 
         # Auto
         else:
-            duration = _bio_analyze_findduration(data, sampling_rate=sampling_rate)
-            if duration >= 10:
-                rsa = _bio_analyze_rsa_interval(data, sampling_rate=sampling_rate)
-            else:
-                rsa = _bio_analyze_rsa_event(data)
+            raise ValueError("Wrong `method` argument.")
 
         features = pd.concat([features, rsa], axis=1, sort=False)
 
@@ -222,7 +212,7 @@ def bio_analyze(data, sampling_rate=1000, method="auto", window_lengths='constan
 # =============================================================================
 # Internals
 # =============================================================================
-def _bio_analyze_slicewindow(data, window_lengths, signal='ECG'):
+def _bio_analyze_slicewindow(data, window_lengths, signal="ECG"):
 
     if signal in window_lengths.keys():
         start = window_lengths[signal][0]
@@ -255,7 +245,6 @@ def _bio_analyze_findduration(data, sampling_rate=1000):
 def _bio_analyze_rsa_interval(data, sampling_rate=1000):
     # RSA features for interval-related analysis
 
-
     if isinstance(data, pd.DataFrame):
         rsa = hrv_rsa(data, sampling_rate=sampling_rate, continuous=False)
         rsa = pd.DataFrame.from_dict(rsa, orient="index").T
@@ -270,21 +259,19 @@ def _bio_analyze_rsa_interval(data, sampling_rate=1000):
     return rsa
 
 
-def _bio_analyze_rsa_event(data, rsa={}):
+def _bio_analyze_rsa_event(data):
     # RSA features for event-related analysis
-
+    rsa = {}
     if isinstance(data, dict):
         for i in data:
-            rsa[i] = {}
-            rsa[i] = _bio_analyze_rsa_epoch(data[i], rsa[i])
+            rsa[i] = _bio_analyze_rsa_epoch(data[i])
         rsa = pd.DataFrame.from_dict(rsa, orient="index")
 
     elif isinstance(data, pd.DataFrame):
-
         # Convert back to dict
-        for label, df in data.groupby('Label'):
+        for label, df in data.groupby("Label"):
             rsa[label] = {}
-            epoch = df.set_index('Time')
+            epoch = df.set_index("Time")
             rsa[label] = _bio_analyze_rsa_epoch(epoch, rsa[label])
         rsa = pd.DataFrame.from_dict(rsa, orient="index")
         # Fix index sorting to combine later with features dataframe
@@ -295,8 +282,9 @@ def _bio_analyze_rsa_event(data, rsa={}):
     return rsa
 
 
-def _bio_analyze_rsa_epoch(epoch, output={}):
+def _bio_analyze_rsa_epoch(epoch):
     # RSA features for event-related analysis: epoching
+    output = {}
 
     # To remove baseline
     if np.min(epoch.index.values) <= 0:
