@@ -9,21 +9,37 @@ from ..misc import NeuroKitWarning, as_vector
 from ..signal import signal_filter
 
 
-def ecg_clean(ecg_signal, sampling_rate=1000, method="neurokit"):
-    """Clean an ECG signal.
+def ecg_clean(ecg_signal, sampling_rate=1000, method="neurokit", **kwargs):
+    """**ECG Signal Cleaning**
+
+    Clean an ECG signal to remove noise and improve peak-detection accuracy. Different cleaning
+    method are implemented.
+
+    * ``'neurokit'`` (default): 0.5 Hz high-pass butterworth filter (order = 5), followed by
+      powerline filtering (see ``signal_filter()``). By default, ``powerline = 50``.
+    * ``'biosppy'``: Same as in the biosppy package. **Please help providing a better description!**
+    * ``'pantompkins1985'``: Method used in Pan & Tompkins (1985). **Please help providing a better
+      description!**
+    * ``'hamilton2002'``: Method used in Hamilton (2002). **Please help providing a better
+      description!**
+    * ``'elgendi2010'``: Method used in Elgendi et al. (2010). **Please help providing a better
+      description!**
+    * ``'engzeemod2012'``: Method used in Engelse & Zeelenberg (1979). **Please help providing a
+      better description!**
 
-    Prepare a raw ECG signal for R-peak detection with the specified method.
 
     Parameters
     ----------
     ecg_signal : Union[list, np.array, pd.Series]
         The raw ECG channel.
     sampling_rate : int
-        The sampling frequency of `ecg_signal` (in Hz, i.e., samples/second).
-        Defaults to 1000.
+        The sampling frequency of ``ecg_signal`` (in Hz, i.e., samples/second). Defaults to 1000.
     method : str
-        The processing pipeline to apply. Can be one of 'neurokit' (default),
-        'biosppy', 'pantompkins1985', 'hamilton2002', 'elgendi2010', 'engzeemod2012'.
+        The processing pipeline to apply. Can be one of ``"neurokit"`` (default),
+        ``"biosppy"``, ``"pantompkins1985"``, ``"hamilton2002"``, ``"elgendi2010"``,
+        ``"engzeemod2012"``.
+    **kwargs
+        Other arguments to be passed to specific methods.
 
     Returns
     -------
@@ -32,33 +48,39 @@ def ecg_clean(ecg_signal, sampling_rate=1000, method="neurokit"):
 
     See Also
     --------
-    ecg_findpeaks, signal_rate, ecg_process, ecg_plot
+    ecg_peaks, ecg_process, ecg_plot, .signal_rate, .signal_filter
 
     Examples
     --------
+    .. ipython:: python
 
-    >>> import pandas as pd
-    >>> import neurokit2 as nk
-    >>> import matplotlib.pyplot as plt
-    >>>
-    >>> ecg = nk.ecg_simulate(duration=10, sampling_rate=1000)
-    >>> signals = pd.DataFrame({"ECG_Raw" : ecg,
-    ...                         "ECG_NeuroKit" : nk.ecg_clean(ecg, sampling_rate=1000, method="neurokit"),
-    ...                         "ECG_BioSPPy" : nk.ecg_clean(ecg, sampling_rate=1000, method="biosppy"),
-    ...                         "ECG_PanTompkins" : nk.ecg_clean(ecg, sampling_rate=1000, method="pantompkins1985"),
-    ...                         "ECG_Hamilton" : nk.ecg_clean(ecg, sampling_rate=1000, method="hamilton2002"),
-    ...                         "ECG_Elgendi" : nk.ecg_clean(ecg, sampling_rate=1000, method="elgendi2010"),
-    ...                         "ECG_EngZeeMod" : nk.ecg_clean(ecg, sampling_rate=1000, method="engzeemod2012")})
-     >>> signals.plot() #doctest: +ELLIPSIS
-     <AxesSubplot:>
+      import pandas as pd
+      import neurokit2 as nk
+      import matplotlib.pyplot as plt
+
+      ecg = nk.ecg_simulate(duration=10, sampling_rate=1000)
+      signals = pd.DataFrame({"ECG_Raw" : ecg,
+                              "ECG_NeuroKit" : nk.ecg_clean(ecg, sampling_rate=1000, method="neurokit"),
+                              "ECG_BioSPPy" : nk.ecg_clean(ecg, sampling_rate=1000, method="biosppy"),
+                              "ECG_PanTompkins" : nk.ecg_clean(ecg, sampling_rate=1000, method="pantompkins1985"),
+                              "ECG_Hamilton" : nk.ecg_clean(ecg, sampling_rate=1000, method="hamilton2002"),
+                              "ECG_Elgendi" : nk.ecg_clean(ecg, sampling_rate=1000, method="elgendi2010"),
+                              "ECG_EngZeeMod" : nk.ecg_clean(ecg, sampling_rate=1000, method="engzeemod2012")})
+      @savefig p_ecg_clean.png scale=100%
+      signals.plot()
 
 
     References
     --------------
-    - Jiapu Pan and Willis J. Tompkins. A Real-Time QRS Detection Algorithm. In: IEEE Transactions on
-      Biomedical Engineering BME-32.3 (1985), pp. 230–236.
-
-    - Hamilton, Open Source ECG Analysis Software Documentation, E.P.Limited, 2002.
+    * Engelse, W. A., & Zeelenberg, C. (1979). A single scan algorithm for QRS-detection and
+      feature extraction. Computers in cardiology, 6(1979), 37-42.
+    * Pan, J., & Tompkins, W. J. (1985). A real-time QRS detection algorithm. IEEE transactions
+      on biomedical engineering, (3), 230-236.
+    * Hamilton, P. (2002). Open source ECG analysis. In Computers in cardiology (pp. 101-104).
+      IEEE.
+    * Elgendi, M., Jonkman, M., & De Boer, F. (2010). Frequency Bands Effects on QRS Detection.
+      Biosignals, Proceedings of the Third International Conference on Bio-inspired Systems and
+      Signal Processing, 428-431.
 
     """
     ecg_signal = as_vector(ecg_signal)
@@ -75,7 +97,7 @@ def ecg_clean(ecg_signal, sampling_rate=1000, method="neurokit"):
 
     method = method.lower()  # remove capitalised letters
     if method in ["nk", "nk2", "neurokit", "neurokit2"]:
-        clean = _ecg_clean_nk(ecg_signal, sampling_rate)
+        clean = _ecg_clean_nk(ecg_signal, sampling_rate, **kwargs)
     elif method in ["biosppy", "gamboa2008"]:
         clean = _ecg_clean_biosppy(ecg_signal, sampling_rate)
     elif method in ["pantompkins", "pantompkins1985"]:
@@ -120,18 +142,16 @@ def _ecg_clean_missing(ecg_signal):
 
 
 # =============================================================================
-# Neurokit
+# NeuroKit
 # =============================================================================
-def _ecg_clean_nk(ecg_signal, sampling_rate=1000):
+def _ecg_clean_nk(ecg_signal, sampling_rate=1000, **kwargs):
 
     # Remove slow drift and dc offset with highpass Butterworth.
     clean = signal_filter(
         signal=ecg_signal, sampling_rate=sampling_rate, lowcut=0.5, method="butterworth", order=5
     )
 
-    clean = signal_filter(
-        signal=clean, sampling_rate=sampling_rate, method="powerline", powerline=50
-    )
+    clean = signal_filter(signal=clean, sampling_rate=sampling_rate, method="powerline", **kwargs)
     return clean
 
 
