@@ -7,70 +7,75 @@ from ..signal import signal_filter, signal_findpeaks, signal_smooth, signal_zero
 
 
 def eda_findpeaks(eda_phasic, sampling_rate=1000, method="neurokit", amplitude_min=0.1):
-    """Identify Skin Conductance Responses (SCR) in Electrodermal Activity (EDA).
+    """**Identify Skin Conductance Responses (SCR) in Electrodermal Activity (EDA)**
 
-    Low-level function used by `eda_peaks()` to identify Skin Conductance Responses (SCR) peaks in the
-    phasic component of Electrodermal Activity (EDA) with different possible methods. See `eda_peaks()` for details.
+    Low-level function used by `eda_peaks()` to identify Skin Conductance Responses (SCR) peaks in
+    the phasic component of Electrodermal Activity (EDA) with different possible methods. See
+    :func:`eda_peaks` for details.
 
     Parameters
     ----------
     eda_phasic : Union[list, np.array, pd.Series]
-        The phasic component of the EDA signal (from `eda_phasic()`).
+        The phasic component of the EDA signal (from :func:`eda_phasic`).
     sampling_rate : int
         The sampling frequency of the EDA signal (in Hz, i.e., samples/second).
     method : str
-        The processing pipeline to apply. Can be one of "neurokit" (default),
-        "gamboa2008", "kim2004" (the default in BioSPPy), "vanhalem2020" or "nabian2018".
+        The processing pipeline to apply. Can be one of ``"neurokit"`` (default),
+        ``"gamboa2008"``, ``"kim2004"`` (the default in BioSPPy), ``"vanhalem2020"`` or ``"nabian2018"``.
     amplitude_min : float
-        Only used if 'method' is 'neurokit' or 'kim2004'. Minimum threshold by which to exclude
-        SCRs (peaks) as relative to the largest amplitude in the signal.
+        Only used if "method" is ``"neurokit"`` or ``"kim2004"``. Minimum threshold by which to
+        exclude SCRs (peaks) as relative to the largest amplitude in the signal.
 
     Returns
     -------
     info : dict
-        A dictionary containing additional information, in this case the aplitude of the SCR, the samples
-        at which the SCR onset and the SCR peaks occur. Accessible with the keys "SCR_Amplitude",
-        "SCR_Onsets", and "SCR_Peaks" respectively.
+        A dictionary containing additional information, in this case the aplitude of the SCR, the
+        samples at which the SCR onset and the SCR peaks occur. Accessible with the keys
+        ``"SCR_Amplitude"``, ``"SCR_Onsets"``, and ``"SCR_Peaks"`` respectively.
 
     See Also
     --------
     eda_simulate, eda_clean, eda_phasic, eda_fixpeaks, eda_peaks, eda_process, eda_plot
 
 
-
     Examples
     ---------
-    >>> import neurokit2 as nk
-    >>>
-    >>> # Get phasic component
-    >>> eda_signal = nk.eda_simulate(duration=30, scr_number=5, drift=0.1, noise=0)
-    >>> eda_cleaned = nk.eda_clean(eda_signal)
-    >>> eda = nk.eda_phasic(eda_cleaned)
-    >>> eda_phasic = eda["EDA_Phasic"].values
-    >>>
-    >>> # Find peaks
-    >>> gamboa2008 = nk.eda_findpeaks(eda_phasic, method="gamboa2008")
-    >>> kim2004 = nk.eda_findpeaks(eda_phasic, method="kim2004")
-    >>> neurokit = nk.eda_findpeaks(eda_phasic, method="neurokit")
-    >>> vanhalem2020 = nk.eda_findpeaks(eda_phasic, method="vanhalem2020")
-    >>> nabian2018 = nk.eda_findpeaks(eda_phasic, method="nabian2018")
-    >>> fig = nk.events_plot([gamboa2008["SCR_Peaks"], kim2004["SCR_Peaks"], vanhalem2020["SCR_Peaks"],
-    ...                       neurokit["SCR_Peaks"], nabian2018["SCR_Peaks"]], eda_phasic)
-    >>> fig #doctest: +SKIP
+    .. ipython:: python
+
+      import neurokit2 as nk
+
+      # Get phasic component
+      eda_signal = nk.eda_simulate(duration=30, scr_number=5, drift=0.1, noise=0)
+      eda_cleaned = nk.eda_clean(eda_signal)
+      eda = nk.eda_phasic(eda_cleaned)
+      eda_phasic = eda["EDA_Phasic"].values
+
+      # Find peaks
+      gamboa2008 = nk.eda_findpeaks(eda_phasic, method="gamboa2008")
+      kim2004 = nk.eda_findpeaks(eda_phasic, method="kim2004")
+      neurokit = nk.eda_findpeaks(eda_phasic, method="neurokit")
+      vanhalem2020 = nk.eda_findpeaks(eda_phasic, method="vanhalem2020")
+      nabian2018 = nk.eda_findpeaks(eda_phasic, method="nabian2018")
+      @savefig p_eda_findpeaks.png scale=100%
+      nk.events_plot([gamboa2008["SCR_Peaks"], kim2004["SCR_Peaks"], vanhalem2020["SCR_Peaks"],
+                           neurokit["SCR_Peaks"], nabian2018["SCR_Peaks"]], eda_phasic)
+      @suppress
+      plt.close()
 
     References
     ----------
-    - Gamboa, H. (2008). Multi-modal behavioral biometrics based on hci and electrophysiology.
+    * Gamboa, H. (2008). Multi-modal behavioral biometrics based on hci and electrophysiology.
       PhD ThesisUniversidade.
 
-    - Kim, K. H., Bang, S. W., & Kim, S. R. (2004). Emotion recognition system using short-term monitoring
-      of physiological signals. Medical and biological engineering and computing, 42(3), 419-427.
+    * Kim, K. H., Bang, S. W., & Kim, S. R. (2004). Emotion recognition system using short-term
+      monitoring of physiological signals. Medical and biological engineering and computing, 42(3),
+      419-427.
 
-    - van Halem, S., Van Roekel, E., Kroencke, L., Kuper, N., & Denissen, J. (2020).
+    * van Halem, S., Van Roekel, E., Kroencke, L., Kuper, N., & Denissen, J. (2020).
       Moments That Matter? On the Complexity of Using Triggers Based on Skin Conductance to Sample
       Arousing Events Within an Experience Sampling Framework. European Journal of Personality.
 
-    - Nabian, M., Yin, Y., Wormwood, J., Quigley, K. S., Barrett, L. F., & Ostadabbas, S. (2018). An
+    * Nabian, M., Yin, Y., Wormwood, J., Quigley, K. S., Barrett, L. F., & Ostadabbas, S. (2018). An
       Open-Source Feature Extraction Tool for the Analysis of Peripheral Physiological Data. IEEE
       journal of translational engineering in health and medicine, 6, 2800711.
       https://doi.org/10.1109/JTEHM.2018.2878000
@@ -81,13 +86,17 @@ def eda_findpeaks(eda_phasic, sampling_rate=1000, method="neurokit", amplitude_m
         try:
             eda_phasic = eda_phasic["EDA_Phasic"]
         except KeyError:
-            raise KeyError("NeuroKit error: eda_findpeaks(): Please provide an array as the input signal.")
+            raise KeyError(
+                "NeuroKit error: eda_findpeaks(): Please provide an array as the input signal."
+            )
 
     method = method.lower()  # remove capitalised letters
     if method in ["gamboa2008", "gamboa"]:
         info = _eda_findpeaks_gamboa2008(eda_phasic)
     elif method in ["kim", "kbk", "kim2004", "biosppy"]:
-        info = _eda_findpeaks_kim2004(eda_phasic, sampling_rate=sampling_rate, amplitude_min=amplitude_min)
+        info = _eda_findpeaks_kim2004(
+            eda_phasic, sampling_rate=sampling_rate, amplitude_min=amplitude_min
+        )
     elif method in ["nk", "nk2", "neurokit", "neurokit2"]:
         info = _eda_findpeaks_neurokit(eda_phasic, amplitude_min=amplitude_min)
     elif method in ["vanhalem2020", "vanhalem", "halem2020"]:
@@ -112,7 +121,11 @@ def _eda_findpeaks_neurokit(eda_phasic, amplitude_min=0.1):
 
     peaks = signal_findpeaks(eda_phasic, relative_height_min=amplitude_min, relative_max=True)
 
-    info = {"SCR_Onsets": peaks["Onsets"], "SCR_Peaks": peaks["Peaks"], "SCR_Height": eda_phasic[peaks["Peaks"]]}
+    info = {
+        "SCR_Onsets": peaks["Onsets"],
+        "SCR_Peaks": peaks["Peaks"],
+        "SCR_Height": eda_phasic[peaks["Peaks"]],
+    }
 
     return info
 
@@ -148,7 +161,12 @@ def _eda_findpeaks_vanhalem2020(eda_phasic, sampling_rate=1000):
     """
     # smooth
     eda_phasic = signal_filter(
-        eda_phasic, sampling_rate=sampling_rate, lowcut=None, highcut=None, method="savgol", window_size=501
+        eda_phasic,
+        sampling_rate=sampling_rate,
+        lowcut=None,
+        highcut=None,
+        method="savgol",
+        window_size=501,
     )
     info = signal_findpeaks(eda_phasic)
     peaks = info["Peaks"]
@@ -167,7 +185,11 @@ def _eda_findpeaks_vanhalem2020(eda_phasic, sampling_rate=1000):
         keep = np.where(decrease > threshold)[0]
         idx = idx[keep]  # Update index
 
-    info = {"SCR_Onsets": info["Onsets"][idx], "SCR_Peaks": info["Peaks"][idx], "SCR_Height": info["Height"][idx]}
+    info = {
+        "SCR_Onsets": info["Onsets"][idx],
+        "SCR_Peaks": info["Peaks"][idx],
+        "SCR_Height": info["Height"][idx],
+    }
 
     return info
 
@@ -204,7 +226,9 @@ def _eda_findpeaks_gamboa2008(eda_phasic):
 
     # sanity check
     if len(pi) == 0 or len(ni) == 0:
-        raise ValueError("NeuroKit error: eda_findpeaks(): Could not find enough SCR peaks. Try another method.")
+        raise ValueError(
+            "NeuroKit error: eda_findpeaks(): Could not find enough SCR peaks. Try another method."
+        )
 
     # pair vectors
     if ni[0] < pi[0]:
@@ -333,9 +357,9 @@ def _eda_findpeaks_nabian2018(eda_phasic):
 
     # Sanitize consecutive crossings
     if len(pos_crossings) > len(neg_crossings):
-        pos_crossings = pos_crossings[0:len(neg_crossings)]
+        pos_crossings = pos_crossings[0 : len(neg_crossings)]
     elif len(pos_crossings) < len(neg_crossings):
-        neg_crossings = neg_crossings[0:len(pos_crossings)]
+        neg_crossings = neg_crossings[0 : len(pos_crossings)]
 
     peaks_list = []
     onsets_list = []
@@ -353,7 +377,10 @@ def _eda_findpeaks_nabian2018(eda_phasic):
             amps_list.append(amp)
 
     # output
-    info = {"SCR_Onsets": np.array(onsets_list), "SCR_Peaks": np.hstack(np.array(peaks_list)),
-            "SCR_Height": np.array(amps_list)}
+    info = {
+        "SCR_Onsets": np.array(onsets_list),
+        "SCR_Peaks": np.hstack(np.array(peaks_list)),
+        "SCR_Height": np.array(amps_list),
+    }
 
     return info
