@@ -10,38 +10,37 @@ from .eda_fixpeaks import eda_fixpeaks
 
 
 def eda_peaks(eda_phasic, sampling_rate=1000, method="neurokit", amplitude_min=0.1):
-    """Identify Skin Conductance Responses (SCR) in Electrodermal Activity (EDA).
+    """**Identify Skin Conductance Responses (SCR) in Electrodermal Activity (EDA)**
 
     Identify Skin Conductance Responses (SCR) peaks in the phasic component of
     Electrodermal Activity (EDA) with different possible methods, such as:
 
-    - `Gamboa, H. (2008)
-    <http://www.lx.it.pt/~afred/pub/thesisHugoGamboa.pdf>`_
-    - `Kim et al. (2004)
-    <http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.102.7385&rep=rep1&type=pdf>`_
+    * `Gamboa, H. (2008) <http://www.lx.it.pt/~afred/pub/thesisHugoGamboa.pdf>`_
+    * `Kim et al. (2004) <http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.102.7385&rep=rep1&type=pdf>`_
 
     Parameters
     ----------
     eda_phasic : Union[list, np.array, pd.Series]
-        The phasic component of the EDA signal (from `eda_phasic()`).
+        The phasic component of the EDA signal (from :func:`eda_phasic()`).
     sampling_rate : int
         The sampling frequency of the EDA signal (in Hz, i.e., samples/second).
     method : str
-        The processing pipeline to apply. Can be one of "neurokit" (default),
-        "gamboa2008", "kim2004" (the default in BioSPPy), "vanhalem2020" or "nabian2018".
+        The processing pipeline to apply. Can be one of ``"neurokit"`` (default),
+        ``"gamboa2008"``, ``"kim2004"`` (the default in BioSPPy), ``"vanhalem2020"`` or ``"nabian2018"``.
     amplitude_min : float
-        Only used if 'method' is 'neurokit' or 'kim2004'. Minimum threshold by which to exclude
-        SCRs (peaks) as relative to the largest amplitude in the signal.
+        Only used if ``method`` is ``"neurokit"`` or ``"kim2004"``. Minimum threshold by which to
+        exclude SCRs (peaks) as relative to the largest amplitude in the signal.
 
     Returns
     -------
     info : dict
-        A dictionary containing additional information, in this case the aplitude of the SCR, the samples
-        at which the SCR onset and the SCR peaks occur. Accessible with the keys "SCR_Amplitude",
-        "SCR_Onsets", and "SCR_Peaks" respectively. It also contains the signals' sampling rate.
+        A dictionary containing additional information, in this case the aplitude of the SCR, the
+        samples at which the SCR onset and the SCR peaks occur. Accessible with the keys
+        ``"SCR_Amplitude"``, ``"SCR_Onsets"``, and ``"SCR_Peaks"`` respectively. It also contains the signals' sampling rate.
     signals : DataFrame
-        A DataFrame of same length as the input signal in which occurences of SCR peaks are marked as
-        "1" in lists of zeros with the same length as `eda_cleaned`. Accessible with the keys "SCR_Peaks".
+        A DataFrame of same length as the input signal in which occurences of SCR peaks are marked
+        as "1" in lists of zeros with the same length as ``"eda_cleaned"``. Accessible with the keys
+        ``"SCR_Peaks"``.
 
     See Also
     --------
@@ -51,34 +50,43 @@ def eda_peaks(eda_phasic, sampling_rate=1000, method="neurokit", amplitude_min=0
 
     Examples
     ---------
-    >>> import neurokit2 as nk
-    >>>
-    >>> # Get phasic component
-    >>> eda_signal = nk.eda_simulate(duration=30, scr_number=5, drift=0.1, noise=0, sampling_rate=100)
-    >>> eda_cleaned = nk.eda_clean(eda_signal, sampling_rate=100)
-    >>> eda = nk.eda_phasic(eda_cleaned, sampling_rate=100)
-    >>> eda_phasic = eda["EDA_Phasic"].values
-    >>>
-    >>> # Find peaks
-    >>> _, kim2004 = nk.eda_peaks(eda_phasic, method="kim2004")
-    >>> _, neurokit = nk.eda_peaks(eda_phasic, method="neurokit")
-    >>> _, nabian2018 = nk.eda_peaks(eda_phasic, method="nabian2018")
-    >>> nk.events_plot([nabian2018["SCR_Peaks"], kim2004["SCR_Peaks"], neurokit["SCR_Peaks"]], eda_phasic) #doctest: +ELLIPSIS
-    <Figure ...>
+    .. ipython:: python
+
+      import neurokit2 as nk
+
+      # Get phasic component
+      eda_signal = nk.eda_simulate(duration=30, scr_number=5, drift=0.1, noise=0, sampling_rate=100)
+      eda_cleaned = nk.eda_clean(eda_signal, sampling_rate=100)
+      eda = nk.eda_phasic(eda_cleaned, sampling_rate=100)
+      eda_phasic = eda["EDA_Phasic"].values
+
+      # Find peaks
+      _, kim2004 = nk.eda_peaks(eda_phasic, method="kim2004")
+      _, neurokit = nk.eda_peaks(eda_phasic, method="neurokit")
+      _, nabian2018 = nk.eda_peaks(eda_phasic, method="nabian2018")
+
+      @savefig p_eda_peaks.png scale=100%
+      nk.events_plot([
+          nabian2018["SCR_Peaks"],
+          kim2004["SCR_Peaks"],
+          neurokit["SCR_Peaks"]
+      ], eda_phasic)
+      @suppress
+      plt.close()
 
     References
     ----------
-    - Gamboa, H. (2008). Multi-modal behavioral biometrics based on hci and electrophysiology.
+    * Gamboa, H. (2008). Multi-modal behavioral biometrics based on hci and electrophysiology.
       PhD ThesisUniversidade.
-    - Kim, K. H., Bang, S. W., & Kim, S. R. (2004). Emotion recognition system using short-term monitoring
-      of physiological signals. Medical and biological engineering and computing, 42(3), 419-427.
-    - van Halem, S., Van Roekel, E., Kroencke, L., Kuper, N., & Denissen, J. (2020).
+    * Kim, K. H., Bang, S. W., & Kim, S. R. (2004). Emotion recognition system using short-term
+      monitoring of physiological signals. Medical and biological engineering and computing, 42(3),
+      419-427.
+    * van Halem, S., Van Roekel, E., Kroencke, L., Kuper, N., & Denissen, J. (2020).
       Moments That Matter? On the Complexity of Using Triggers Based on Skin Conductance to Sample
       Arousing Events Within an Experience Sampling Framework. European Journal of Personality.
-    - Nabian, M., Yin, Y., Wormwood, J., Quigley, K. S., Barrett, L. F., & Ostadabbas, S. (2018). An
+    * Nabian, M., Yin, Y., Wormwood, J., Quigley, K. S., Barrett, L. F., & Ostadabbas, S. (2018). An
       Open-Source Feature Extraction Tool for the Analysis of Peripheral Physiological Data. IEEE
       journal of translational engineering in health and medicine, 6, 2800711.
-      https://doi.org/10.1109/JTEHM.2018.2878000
 
     """
     if isinstance(eda_phasic, (pd.DataFrame, pd.Series)):
