@@ -17,159 +17,119 @@ from .hrv_utils import _hrv_get_rri, _hrv_sanitize_input
 
 
 def hrv_nonlinear(peaks, sampling_rate=1000, show=False, **kwargs):
-    """Computes nonlinear indices of Heart Rate Variability (HRV).
+    """**Computes nonlinear indices of Heart Rate Variability (HRV)**
 
-    See `Pham et al. (2021) <https://www.mdpi.com/1424-8220/21/12/3998>`_ and
-    `Lau et al. (2021) <https://psyarxiv.com/f8k3x/>`_.
+    Non-linear indices include features derived from the *Poincaré plot*, as well as other
+    :func:`.complexity` indices. Note that there exist many more complexity indices that are
+    available in NeuroKit2 and that could be applied to HRV. The :func:`.hrv_nonlinear` function
+    only includes the most commonly used indices.
+
+    The **Poincaré plot** is a graphical representation of each NN interval plotted against its
+    preceding NN interval. The ellipse that emerges is a visual quantification of the correlation
+    between successive NN intervals.
+
+    Indices derived from the Poincaré plot analysis are:
+
+    * **SD1**: Standard deviation perpendicular to the line of identity. It is an index of
+      short-term RR interval fluctuations, i.e., beat-to-beat variability. It is equivalent
+      (although on another scale) to RMSSD, and therefore it is redundant to report correlation
+      with both.
+    * **SD2**: Standard deviation along the identity line. Index of long-term HRV changes.
+    * **SD1/SD2**: ratio of *SD1* to *SD2*. Describes the ratio of short term to long term
+      variations in HRV.
+    * **S**: Area of ellipse described by *SD1* and *SD2* (``pi * SD1 * SD2``). It is
+      proportional to *SD1SD2*.
+    * **CSI**: The Cardiac Sympathetic Index (Toichi, 1997) is a measure of cardiac sympathetic
+      function independent of vagal activity, calculated by dividing the longitudinal variability of
+      the Poincaré plot (``4*SD2``) by its transverse variability (``4*SD1``).
+    * **CVI**: The Cardiac Vagal Index (Toichi, 1997) is an index of cardiac parasympathetic
+      function (vagal activity unaffected by sympathetic activity), and is equal equal to the
+      logarithm of the product of longitudinal (``4*SD2``) and transverse variability (``4*SD1``).
+    * **CSI_Modified**: The modified CSI (Jeppesen, 2014) obtained by dividing the square of the
+      longitudinal variability by its transverse variability.
+
+    Indices of **Heart Rate Asymmetry** (HRA), i.e., asymmetry of the Poincaré plot (Yan, 2017),
+    include:
+
+    * **GI**: Guzik's Index, defined as the distance of points above line of identity (LI) to LI
+      divided by the distance of all points in Poincaré plot to LI except those that are located on
+      LI.
+    * **SI**: Slope Index, defined as the phase angle of points above LI divided by the phase angle
+      of all points in Poincaré plot except those that are located on LI.
+    * **AI**: Area Index, defined as the cumulative area of the sectors corresponding to the points
+      that are located above LI divided by the cumulative area of sectors corresponding to all
+      points in the Poincaré plot except those that are located on LI.
+    * **PI**: Porta's Index, defined as the number of points below LI divided by the total number
+      of points in Poincaré plot except those that are located on LI.
+    * **SD1d** and **SD1a**: short-term variance of contributions of decelerations (prolongations
+      of RR intervals) and accelerations (shortenings of RR intervals), respectively (Piskorski,
+      2011)
+    * **C1d** and **C1a**: the contributions of heart rate decelerations and accelerations to s
+      short-term HRV, respectively (Piskorski,  2011).
+    * **SD2d** and **SD2a**: long-term variance of contributions of decelerations (prolongations of
+      RR intervals) and accelerations (shortenings of RR intervals), respectively (Piskorski, 2011).
+    * **C2d** and **C2a**: the contributions of heart rate decelerations and accelerations to
+      long-term HRV, respectively (Piskorski,  2011).
+    * **SDNNd** and **SDNNa**: total variance of contributions of decelerations (prolongations of
+      RR intervals) and accelerations (shortenings of RR intervals), respectively (Piskorski, 2011).
+    * **Cd** and **Ca**: the total contributions of heart rate decelerations and accelerations to
+      HRV.
+
+    Indices of **Heart Rate Fragmentation** (Costa, 2017) include:
+
+    * **PIP**: Percentage of inflection points of the RR intervals series.
+    * **IALS**: Inverse of the average length of the acceleration/deceleration segments.
+    * **PSS**: Percentage of short segments.
+    * **PAS**: IPercentage of NN intervals in alternation segments.
+
+    Indices of **Complexity** and **Fractal Physiology** include:
+
+    * **ApEn**: See :func:`.entropy_approximate`.
+    * **SampEn**: See :func:`.entropy_sample`.
+    * **ShanEn**: See :func:`.entropy_shannon`.
+    * **FuzzyEn**: See :func:`.entropy_fuzzy`.
+    * **MSE**: See :func:`.entropy_multiscale`.
+    * **CMSE**: See :func:`.entropy_multiscale`.
+    * **RCMSE**: See :func:`.entropy_multiscale`.
+    * **CD**: See :func:`.fractal_correlation`.
+    * **HFD**: See :func:`.fractal_higuchi` (with ``kmax`` set to ``"default"``).
+    * **KFD**: See :func:`.fractal_katz`.
+    * **LZC**: See :func:`.fractal_lempelziv`.
+    * **DFA_alpha1**: The monofractal detrended fluctuation analysis of the HR signal,
+      corresponding to short-term correlations. See :func:`.fractal_dfa`.
+    * **DFA_alpha2**: The monofractal detrended fluctuation analysis of the HR signal,
+      corresponding to long-term correlations. See :func:`.fractal_dfa`.
+    * **MFDFA indices**: Indices related to the :func:`multifractal spectrum <.fractal_dfa()>`.
+
+    Other non-linear indices include those based on Recurrence Quantification Analysis (RQA), but
+    are not implemented yet (but soon).
+
+    .. tip::
+        We strongly recommend checking our open-access paper `Pham et al. (2021)
+        <https://doi.org/10.3390/s21123998>`_ on HRV indices, as well as `Lau et al. (2021)
+        <https://psyarxiv.com/f8k3x/>`_ on complexity, for more information.
 
     Parameters
     ----------
     peaks : dict
         Samples at which cardiac extrema (i.e., R-peaks, systolic peaks) occur.
-        Can be a list of indices or the output(s) of other functions such as ecg_peaks,
-        ppg_peaks, ecg_process or bio_process.
+        Can be a list of indices or the output(s) of other functions such as :func:`.ecg_peaks`,
+        :func:`.ppg_peaks`, :func:`.ecg_process` or :func:`.bio_process`.
     sampling_rate : int, optional
         Sampling rate (Hz) of the continuous cardiac signal in which the peaks occur. Should be at
         least twice as high as the highest frequency in vhf. By default 1000.
     show : bool, optional
-        If True, will return a Poincaré plot, a scattergram, which plots each RR interval against the
-        next successive one. The ellipse centers around the average RR interval. By default False.
+        If ``True``, will return a Poincaré plot, a scattergram, which plots each RR interval
+        against the next successive one. The ellipse centers around the average RR interval. By
+        default ``False``.
     **kwargs
-        Other arguments to be passed into `fractal_dfa()` and `fractal_correlation()`.
+        Other arguments to be passed into :func:`.fractal_dfa` and :func:`.fractal_correlation`.
 
 
     Returns
     -------
     DataFrame
-        Contains non-linear HRV metrics:
-
-        - **Characteristics of the Poincaré Plot Geometry**:
-
-            - **SD1**: SD1 is a measure of the spread of RR intervals on the Poincaré plot
-            perpendicular to the line of identity. It is an index of short-term RR interval
-            fluctuations, i.e., beat-to-beat variability. It is equivalent (although on another
-            scale) to RMSSD, and therefore it is redundant to report correlations with both
-            (Ciccone, 2017).
-
-            - **SD2**: SD2 is a measure of the spread of RR intervals on the Poincaré plot along the
-            line of identity. It is an index of long-term RR interval fluctuations.
-
-            - **SD1SD2**: the ratio between short and long term fluctuations of the RR intervals
-            (SD1 divided by SD2).
-
-            - **S**: Area of ellipse described by SD1 and SD2 (``pi * SD1 * SD2``). It is
-            proportional to *SD1SD2*.
-
-            - **CSI**: The Cardiac Sympathetic Index (Toichi, 1997), calculated by dividing the
-            longitudinal variability of the Poincaré plot (``4*SD2``) by its transverse variability (``4*SD1``).
-
-            - **CVI**: The Cardiac Vagal Index (Toichi, 1997), equal to the logarithm of the product of
-            longitudinal (``4*SD2``) and transverse variability (``4*SD1``).
-
-            - **CSI_Modified**: The modified CSI (Jeppesen, 2014) obtained by dividing the square of
-            the longitudinal variability by its transverse variability.
-
-        - **Indices of Heart Rate Asymmetry (HRA), i.e., asymmetry of the Poincaré plot** (Yan, 2017):
-
-            - **GI**: Guzik's Index, defined as the distance of points above line of identity (LI)
-            to LI divided by the distance of all points in Poincaré plot to LI except those that
-            are located on LI.
-
-            - **SI**: Slope Index, defined as the phase angle of points above LI divided by the
-            phase angle of all points in Poincaré plot except those that are located on LI.
-
-            - **AI**: Area Index, defined as the cumulative area of the sectors corresponding to
-            the points that are located above LI divided by the cumulative area of sectors
-            corresponding to all points in the Poincaré plot except those that are located on LI.
-
-            - **PI**: Porta's Index, defined as the number of points below LI divided by the total
-            number of points in Poincaré plot except those that are located on LI.
-
-            - **SD1d** and **SD1a**: short-term variance of contributions of decelerations
-            (prolongations of RR intervals) and accelerations (shortenings of RR intervals),
-            respectively (Piskorski,  2011).
-
-            - **C1d** and **C1a**: the contributions of heart rate decelerations and accelerations
-            to short-term HRV, respectively (Piskorski,  2011).
-
-            - **SD2d** and **SD2a**: long-term variance of contributions of decelerations
-            (prolongations of RR intervals) and accelerations (shortenings of RR intervals),
-            respectively (Piskorski,  2011).
-
-            - **C2d** and **C2a**: the contributions of heart rate decelerations and accelerations
-            to long-term HRV, respectively (Piskorski,  2011).
-
-            - **SDNNd** and **SDNNa**: total variance of contributions of decelerations
-            (prolongations of RR intervals) and accelerations (shortenings of RR intervals),
-            respectively (Piskorski,  2011).
-
-            - **Cd** and **Ca**: the total contributions of heart rate decelerations and
-            accelerations to HRV.
-
-        - **Indices of Heart Rate Fragmentation** (Costa, 2017):
-
-            - **PIP**: Percentage of inflection points of the RR intervals series.
-
-            - **IALS**: Inverse of the average length of the acceleration/deceleration segments.
-
-            - **PSS**: Percentage of short segments.
-
-            - **PAS**: IPercentage of NN intervals in alternation segments.
-
-        - **Indices of Complexity**:
-
-            - **ApEn**: The approximate entropy measure of HRV, calculated by `entropy_approximate()`.
-
-            - **SampEn**: The sample entropy measure of HRV, calculated by `entropy_sample()`.
-
-            - **ShanEn**: The Shannon entropy measure of HRV, calculated by `entropy_shannon()`.
-
-            - **FuzzyEn**: The fuzzy entropy measure of HRV, calculated by `entropy_fuzzy()`.
-
-            - **MSE**: The multiscale entropy measure of HRV, calculated by `entropy_multiscale()`.
-
-            - **CMSE**: The composite multiscale entropy measure of HRV, calculated by `entropy_multiscale()`.
-
-            - **RCMSE**: The refined composite multiscale entropy measure of HRV, calculated by `entropy_multiscale()`.
-
-            - **CD**: The Correlation Dimension of the HR signal, calculated by `fractal_correlation()`.
-
-            - **HFD**: The Higuchi's Fractal Dimension of the HR signal, calculated by `fractal_higuchi()`.
-            kmax is set to "default".
-
-            - **KFD**: The Katz's Fractal Dimension of the HR signal, calculated by `fractal_katz()`.
-
-            - **LZC**: The Lempel-Ziv complexity of the HR signal, calculated by `fractal_lempelziv()`.
-
-            - **DFA_alpha1**: The monofractal detrended fluctuation analysis of the HR signal corresponding
-            to short-term correlations, calculated by `fractal_dfa()`.
-
-            - **DFA_alpha2**: The monofractal detrended fluctuation analysis of the HR signal corresponding
-            to long-term correlations, calculated by `fractal_dfa()`.
-
-            - **DFA_alpha1_ExpRange**: The multifractal detrended fluctuation analysis of the HR signal
-            corresponding to short-term correlations, calculated by `fractal_dfa()`. ExpRange is the range of
-            singularity exponents, correspoinding to the width of the singularity spectrum.
-
-            - **DFA_alpha2_ExpRange**: The multifractal detrended fluctuation analysis of the HR signal
-            corresponding to long-term correlations, calculated by `fractal_dfa()`. ExpRange is the range of
-            singularity exponents, correspoinding to the width of the singularity spectrum.
-
-            - **DFA_alpha1_ExpMean**: Multifractal DFA. ExpMean is the mean of singularity exponents.
-
-            - **DFA_alpha2_ExpMean**: Multifractal DFA. ExpMean is the mean of singularity exponents.
-
-            - **DFA_alpha1_DimRange**: The multifractal detrended fluctuation analysis of the HR signal
-            corresponding to short-term correlations, calculated by `fractal_dfa()`. DimRange is the range of
-            singularity dimensions, correspoinding to the height of the singularity spectrum.
-
-            - **DFA_alpha2_DimRange**: The multifractal detrended fluctuation analysis of the HR signal
-            corresponding to long-term correlations, calculated by `fractal_dfa()`. DimRange is the range of
-            singularity dimensions, correspoinding to the height of the singularity spectrum.
-
-            - **DFA_alpha1_DimMean**: Multifractal DFA. Dimmean is the mean of singularity dimensions.
-
-            - **DFA_alpha2_DimMean**: Multifractal DFA. Dimmean is the mean of singularity dimensions.
+        Contains non-linear HRV metrics.
 
     See Also
     --------
@@ -177,56 +137,57 @@ def hrv_nonlinear(peaks, sampling_rate=1000, show=False, **kwargs):
 
     Examples
     --------
-    >>> import neurokit2 as nk
-    >>>
-    >>> # Download data
-    >>> data = nk.data("bio_resting_5min_100hz")
-    >>>
-    >>> # Find peaks
-    >>> peaks, info = nk.ecg_peaks(data["ECG"], sampling_rate=100)
-    >>>
-    >>> # Compute HRV indices
-    >>> hrv = nk.hrv_nonlinear(peaks, sampling_rate=100, show=True)
-    >>> hrv #doctest: +SKIP
+    .. ipython:: python
+
+      import neurokit2 as nk
+
+      # Download data
+      data = nk.data("bio_resting_5min_100hz")
+
+      # Find peaks
+      peaks, info = nk.ecg_peaks(data["ECG"], sampling_rate=100)
+
+      # Compute HRV indices
+      @savefig p_hrv_nonlinear1.png scale=100%
+      hrv = nk.hrv_nonlinear(peaks, sampling_rate=100, show=True)
+      @suppress
+      plt.close()
+
+    .. ipython:: python
+
+      hrv
+
 
     References
     ----------
-    - Pham, T., Lau, Z. J., Chen, S. H., & Makowski, D. (2021). Heart Rate Variability in Psychology:
-    A Review of HRV Indices and an Analysis Tutorial. Sensors, 21(12), 3998.
-
-    - Yan, C., Li, P., Ji, L., Yao, L., Karmakar, C., & Liu, C. (2017). Area asymmetry of heart
-    rate variability signal. Biomedical engineering online, 16(1), 112.
-
-    - Ciccone, A. B., Siedlik, J. A., Wecht, J. M., Deckert, J. A., Nguyen, N. D., & Weir, J. P.
-    (2017). Reminder: RMSSD and SD1 are identical heart rate variability metrics. Muscle & nerve,
-    56(4), 674-678.
-
-    - Shaffer, F., & Ginsberg, J. P. (2017). An overview of heart rate variability metrics and norms.
-    Frontiers in public health, 5, 258.
-
-    - Costa, M. D., Davis, R. B., & Goldberger, A. L. (2017). Heart rate fragmentation: a new
-    approach to the analysis of cardiac interbeat interval dynamics. Front. Physiol. 8, 255 (2017).
-
-    - Jeppesen, J., Beniczky, S., Johansen, P., Sidenius, P., & Fuglsang-Frederiksen, A. (2014).
-    Using Lorenz plot and Cardiac Sympathetic Index of heart rate variability for detecting seizures
-    for patients with epilepsy. In 2014 36th Annual International Conference of the IEEE Engineering
-    in Medicine and Biology Society (pp. 4563-4566). IEEE.
-
-    - Piskorski, J., & Guzik, P. (2011). Asymmetric properties of long-term and total heart rate
-    variability. Medical & biological engineering & computing, 49(11), 1289-1297.
-
-    - Stein, P. K. (2002). Assessing heart rate variability from real-world Holter reports. Cardiac
-    electrophysiology review, 6(3), 239-244.
-
-    - Brennan, M. et al. (2001). Do Existing Measures of Poincaré Plot Geometry Reflect Nonlinear
-    Features of Heart Rate Variability?. IEEE Transactions on Biomedical Engineering, 48(11), 1342-1347.
-
-    - Toichi, M., Sugiura, T., Murai, T., & Sengoku, A. (1997). A new method of assessing cardiac
-    autonomic function and its comparison with spectral analysis and coefficient of variation of R–R
-    interval. Journal of the autonomic nervous system, 62(1-2), 79-84.
-
-    - Acharya, R. U., Lim, C. M., & Joseph, P. (2002). Heart rate variability analysis using
-    correlation dimension and detrended fluctuation analysis. Itbm-Rbm, 23(6), 333-339.
+    * Pham, T., Lau, Z. J., Chen, S. H., & Makowski, D. (2021). Heart Rate Variability in
+      Psychology: A Review of HRV Indices and an Analysis Tutorial. Sensors, 21(12), 3998.
+      https://doi.org/10.3390/s21123998
+    * Yan, C., Li, P., Ji, L., Yao, L., Karmakar, C., & Liu, C. (2017). Area asymmetry of heart
+      rate variability signal. Biomedical engineering online, 16(1), 112.
+    * Ciccone, A. B., Siedlik, J. A., Wecht, J. M., Deckert, J. A., Nguyen, N. D., & Weir, J. P.\
+      (2017). Reminder: RMSSD and SD1 are identical heart rate variability metrics. Muscle & nerve,
+      56 (4), 674-678.
+    * Shaffer, F., & Ginsberg, J. P. (2017). An overview of heart rate variability metrics and
+      norms. Frontiers in public health, 5, 258.
+    * Costa, M. D., Davis, R. B., & Goldberger, A. L. (2017). Heart rate fragmentation: a new
+      approach to the analysis of cardiac interbeat interval dynamics. Front. Physiol. 8, 255.
+    * Jeppesen, J., Beniczky, S., Johansen, P., Sidenius, P., & Fuglsang-Frederiksen, A. (2014).
+      Using Lorenz plot and Cardiac Sympathetic Index of heart rate variability for detecting
+      seizures for patients with epilepsy. In 2014 36th Annual International Conference of the IEE
+      Engineering in Medicine and Biology Society (pp. 4563-4566). IEEE.
+    * Piskorski, J., & Guzik, P. (2011). Asymmetric properties of long-term and total heart rate
+      variability. Medical & biological engineering & computing, 49(11), 1289-1297.
+    * Stein, P. K. (2002). Assessing heart rate variability from real-world Holter reports. Cardiac
+      electrophysiology review, 6(3), 239-244.
+    * Brennan, M. et al. (2001). Do Existing Measures of Poincaré Plot Geometry Reflect Nonlinear
+      Features of Heart Rate Variability?. IEEE Transactions on Biomedical Engineering, 48(11),
+      1342-1347.
+    * Toichi, M., Sugiura, T., Murai, T., & Sengoku, A. (1997). A new method of assessing cardiac
+      autonomic function and its comparison with spectral analysis and coefficient of variation of
+      R-R interval. Journal of the autonomic nervous system, 62(1-2), 79-84.
+    * Acharya, R. U., Lim, C. M., & Joseph, P. (2002). Heart rate variability analysis using
+      correlation dimension and detrended fluctuation analysis. Itbm-Rbm, 23(6), 333-339.
 
     """
     # Sanitize input
@@ -254,24 +215,18 @@ def hrv_nonlinear(peaks, sampling_rate=1000, show=False, **kwargs):
 
     # Complexity
     tolerance = 0.2 * np.std(rri, ddof=1)
-    out["ApEn"] = entropy_approximate(rri, delay=1, dimension=2, tolerance=tolerance)[0]
-    out["SampEn"] = entropy_sample(rri, delay=1, dimension=2, tolerance=tolerance)[0]
-    out["ShanEn"] = entropy_shannon(rri)[0]
-    out["FuzzyEn"] = entropy_fuzzy(rri, delay=1, dimension=2, tolerance=tolerance)[0]
-    out["MSE"] = entropy_multiscale(
-        rri, dimension=2, tolerance=tolerance, composite=False, refined=False
-    )[0]
-    out["CMSE"] = entropy_multiscale(
-        rri, dimension=2, tolerance=tolerance, composite=True, refined=False
-    )[0]
-    out["RCMSE"] = entropy_multiscale(
-        rri, dimension=2, tolerance=tolerance, composite=True, refined=True
-    )[0]
+    out["ApEn"], _ = entropy_approximate(rri, delay=1, dimension=2, tolerance=tolerance)
+    out["SampEn"], _ = entropy_sample(rri, delay=1, dimension=2, tolerance=tolerance)
+    out["ShanEn"], _ = entropy_shannon(rri)
+    out["FuzzyEn"], _ = entropy_fuzzy(rri, delay=1, dimension=2, tolerance=tolerance)
+    out["MSEn"], _ = entropy_multiscale(rri, dimension=2, tolerance=tolerance, method="MSEn")
+    out["CMSEn"], _ = entropy_multiscale(rri, dimension=2, tolerance=tolerance, method="CMSEn")
+    out["RCMSEn"], _ = entropy_multiscale(rri, dimension=2, tolerance=tolerance, method="RCMSEn")
 
-    out["CD"] = fractal_correlation(rri, delay=1, dimension=2, **kwargs)[0]
-    out["HFD"] = fractal_higuchi(rri, **kwargs)[0]
-    out["KFD"] = fractal_katz(rri)[0]
-    out["LZC"] = complexity_lempelziv(rri, **kwargs)[0]
+    out["CD"], _ = fractal_correlation(rri, delay=1, dimension=2, **kwargs)
+    out["HFD"], _ = fractal_higuchi(rri, k_max=10, **kwargs)
+    out["KFD"], _ = fractal_katz(rri)
+    out["LZC"], _ = complexity_lempelziv(rri, **kwargs)
 
     if show:
         _hrv_nonlinear_show(rri, out)
@@ -448,10 +403,12 @@ def _hrv_nonlinear_fragmentation(rri, out):
 # =============================================================================
 def _hrv_dfa(peaks, rri, out, n_windows="default", **kwargs):
 
-    if "dfa_windows" in kwargs:
-        dfa_windows = kwargs["dfa_windows"]
-    else:
-        dfa_windows = [(4, 11), (12, None)]
+    # if "dfa_windows" in kwargs:
+    #    dfa_windows = kwargs["dfa_windows"]
+    # else:
+    # dfa_windows = [(4, 11), (12, None)]
+    # consider using dict.get() mthd directly
+    dfa_windows = kwargs.get("dfa_windows", [(4, 11), (12, None)])
 
     # Determine max beats
     if dfa_windows[1][1] is None:
@@ -470,15 +427,13 @@ def _hrv_dfa(peaks, rri, out, n_windows="default", **kwargs):
     # Compute DFA alpha1
     short_window = np.linspace(dfa_windows[0][0], dfa_windows[0][1], n_windows_short).astype(int)
     # For monofractal
-    out["DFA_alpha1"] = fractal_dfa(rri, multifractal=False, windows=short_window, **kwargs)[0]
+    out["DFA_alpha1"], _ = fractal_dfa(rri, multifractal=False, scale=short_window, **kwargs)
     # For multifractal
-    mdfa_alpha1 = fractal_dfa(
-        rri, multifractal=True, q=np.arange(-5, 6), windows=short_window, **kwargs
-    )[1]
-    out["DFA_alpha1_ExpRange"] = mdfa_alpha1["ExpRange"]
-    out["DFA_alpha1_ExpMean"] = mdfa_alpha1["ExpMean"]
-    out["DFA_alpha1_DimRange"] = mdfa_alpha1["DimRange"]
-    out["DFA_alpha1_DimMean"] = mdfa_alpha1["DimMean"]
+    mdfa_alpha1, _ = fractal_dfa(
+        rri, multifractal=True, q=np.arange(-5, 6), scale=short_window, **kwargs
+    )
+    for k in mdfa_alpha1.columns:
+        out["MFDFA_alpha1_" + k] = mdfa_alpha1[k].values[0]
 
     # Compute DFA alpha2
     # sanatize max_beats
@@ -486,7 +441,7 @@ def _hrv_dfa(peaks, rri, out, n_windows="default", **kwargs):
         warn(
             "DFA_alpha2 related indices will not be calculated. "
             "The maximum duration of the windows provided for the long-term correlation is smaller "
-            "than the minimum duration of windows. Refer to the `windows` argument in `nk.fractal_dfa()` "
+            "than the minimum duration of windows. Refer to the `scale` argument in `nk.fractal_dfa()` "
             "for more information.",
             category=NeuroKitWarning,
         )
@@ -494,15 +449,13 @@ def _hrv_dfa(peaks, rri, out, n_windows="default", **kwargs):
     else:
         long_window = np.linspace(dfa_windows[1][0], int(max_beats), n_windows_long).astype(int)
         # For monofractal
-        out["DFA_alpha2"] = fractal_dfa(rri, multifractal=False, windows=long_window, **kwargs)[0]
+        out["DFA_alpha2"], _ = fractal_dfa(rri, multifractal=False, scale=long_window, **kwargs)
         # For multifractal
-        mdfa_alpha2 = fractal_dfa(
-            rri, multifractal=True, q=np.arange(-5, 6), windows=long_window, **kwargs
-        )[1]
-        out["DFA_alpha2_ExpRange"] = mdfa_alpha2["ExpRange"]
-        out["DFA_alpha2_ExpMean"] = mdfa_alpha2["ExpMean"]
-        out["DFA_alpha2_DimRange"] = mdfa_alpha2["DimRange"]
-        out["DFA_alpha2_DimMean"] = mdfa_alpha2["DimMean"]
+        mdfa_alpha2, _ = fractal_dfa(
+            rri, multifractal=True, q=np.arange(-5, 6), scale=long_window, **kwargs
+        )
+        for k in mdfa_alpha2.columns:
+            out["MFDFA_alpha2_" + k] = mdfa_alpha2[k].values[0]
 
     return out
 
@@ -609,7 +562,7 @@ def _hrv_nonlinear_show(rri, out, ax=None, ax_marg_x=None, ax_marg_y=None):
     rad_cc = (xct ** 2 / (width / 2.0) ** 2) + (yct ** 2 / (height / 2.0) ** 2)
 
     points = np.where(rad_cc > 1)[0]
-    ax.plot(ax1[points], ax2[points], "ro", color="k", alpha=0.5, markersize=4)
+    ax.plot(ax1[points], ax2[points], "o", color="k", alpha=0.5, markersize=4)
 
     # SD1 and SD2 arrow
     sd1_arrow = ax.arrow(
