@@ -4,24 +4,23 @@ import pandas as pd
 
 
 def as_vector(x):
-    """Convert to vector.
+    """**Convert to vector**
 
     Examples
     --------
-    >>> import neurokit2 as nk
-    >>>
-    >>> x = nk.as_vector(x=range(3))
-    >>> y = nk.as_vector(x=[0, 1, 2])
-    >>> z = nk.as_vector(x=np.array([0, 1, 2]))
-    >>> z #doctest: +SKIP
-    >>>
-    >>> x = nk.as_vector(x=0)
-    >>> x #doctest: +SKIP
-    >>>
-    >>> x = nk.as_vector(x=pd.Series([0, 1, 2]))
-    >>> y = nk.as_vector(x=pd.DataFrame([0, 1, 2]))
-    >>> y #doctest: +SKIP
-    >>>
+      import neurokit2 as nk
+
+      x = nk.as_vector(x=range(3))
+      y = nk.as_vector(x=[0, 1, 2])
+      z = nk.as_vector(x=np.array([0, 1, 2]))
+      z
+
+      x = nk.as_vector(x=0)
+      x
+
+      x = nk.as_vector(x=pd.Series([0, 1, 2]))
+      y = nk.as_vector(x=pd.DataFrame([0, 1, 2]))
+      y
 
     """
     if isinstance(x, (pd.Series, pd.DataFrame)):
