@@ -5,15 +5,15 @@ import pandas as pd
 
 
 def ppg_plot(ppg_signals, sampling_rate=None):
-    """Visualize photoplethysmogram (PPG) data.
+    """**Visualize photoplethysmogram (PPG) data**
 
     Parameters
     ----------
     ppg_signals : DataFrame
-        DataFrame obtained from `ppg_process()`.
+        DataFrame obtained from :func:`.ppg_process`.
     sampling_rate : int
-        The sampling frequency of the PPG (in Hz, i.e., samples/second). Needs to be supplied if the data
-        should be plotted over time in seconds. Otherwise the data is plotted over samples. Defaults to None.
+        The sampling frequency of the PPG (in Hz, i.e., samples/second). Needs to be supplied if
+        the data should be plotted over time in seconds. Otherwise the data is plotted over samples. Defaults to ``None``.
 
     Returns
     -------
@@ -22,17 +22,21 @@ def ppg_plot(ppg_signals, sampling_rate=None):
 
     Examples
     --------
-    >>> import neurokit2 as nk
-    >>>
-    >>> # Simulate data
-    >>> ppg = nk.ppg_simulate(duration=10, sampling_rate=1000, heart_rate=70)
-    >>>
-    >>> # Process signal
-    >>> signals, info = nk.ppg_process(ppg, sampling_rate=1000)
-    >>>
-    >>> # Plot
-    >>> nk.ppg_plot(signals) #doctest: +ELLIPSIS
-    <Figure ...>
+    .. ipython:: python
+
+      import neurokit2 as nk
+
+      # Simulate data
+      ppg = nk.ppg_simulate(duration=10, sampling_rate=1000, heart_rate=70)
+
+      # Process signal
+      signals, info = nk.ppg_process(ppg, sampling_rate=1000)
+
+      # Plot
+      @savefig p_ppg_plot1.png scale=100%
+      nk.ppg_plot(signals)
+      @suppress
+      plt.close()
 
     See Also
     --------
@@ -68,11 +72,15 @@ def ppg_plot(ppg_signals, sampling_rate=None):
     # Plot cleaned and raw PPG
     ax0.set_title("Raw and Cleaned Signal")
     ax0.plot(x_axis, ppg_signals["PPG_Raw"], color="#B0BEC5", label="Raw", zorder=1)
-    ax0.plot(x_axis, ppg_signals["PPG_Clean"], color="#FB1CF0", label="Cleaned", zorder=1, linewidth=1.5)
+    ax0.plot(
+        x_axis, ppg_signals["PPG_Clean"], color="#FB1CF0", label="Cleaned", zorder=1, linewidth=1.5
+    )
 
     # Plot peaks
     peaks = np.where(ppg_signals["PPG_Peaks"] == 1)[0]
-    ax0.scatter(x_axis[peaks], ppg_signals["PPG_Clean"][peaks], color="#D60574", label="Peaks", zorder=2)
+    ax0.scatter(
+        x_axis[peaks], ppg_signals["PPG_Clean"][peaks], color="#D60574", label="Peaks", zorder=2
+    )
     ax0.legend(loc="upper right")
 
     # Rate
@@ -81,5 +89,3 @@ def ppg_plot(ppg_signals, sampling_rate=None):
     ax1.plot(x_axis, ppg_signals["PPG_Rate"], color="#FB661C", label="Rate", linewidth=1.5)
     ax1.axhline(y=ppg_rate_mean, label="Mean", linestyle="--", color="#FBB41C")
     ax1.legend(loc="upper right")
-
-    return fig
