@@ -20,47 +20,55 @@ def signal_fixpeaks(
     relative_interval_max=None,
     robust=False,
     method="Kubios",
+    **kwargs,
 ):
-    """Correct erroneous peak placements.
+    """**Correct Erroneous Peak Placements**
 
-    Identify and correct erroneous peak placements based on outliers in peak-to-peak differences (period).
+    Identify and correct erroneous peak placements based on outliers in peak-to-peak differences
+    (period).
 
     Parameters
     ----------
     peaks : list or array or DataFrame or Series or dict
-        The samples at which the peaks occur. If an array is passed in, it is assumed that it was obtained
-        with `signal_findpeaks()`. If a DataFrame is passed in, it is assumed to be obtained with `ecg_findpeaks()`
-        or `ppg_findpeaks()` and to be of the same length as the input signal.
+        The samples at which the peaks occur. If an array is passed in, it is assumed that it was
+        obtained with :func:`.signal_findpeaks`. If a DataFrame is passed in, it is assumed to be
+        obtained with :func:`.ecg_findpeaks` or :func:`.ppg_findpeaks` and to be of the same length
+        as the input signal.
     sampling_rate : int
         The sampling frequency of the signal that contains the peaks (in Hz, i.e., samples/second).
     iterative : bool
-        Whether or not to apply the artifact correction repeatedly (results in superior artifact correction).
+        Whether or not to apply the artifact correction repeatedly (results in superior artifact
+        correction).
     show : bool
         Whether or not to visualize artifacts and artifact thresholds.
     interval_min : float
-        The minimum interval between the peaks.
+        Only when ``method = "neurokit"``. The minimum interval between the peaks.
     interval_max : float
-        The maximum interval between the peaks.
+        Only when ``method = "neurokit"``. The maximum interval between the peaks.
     relative_interval_min : float
-        The minimum interval between the peaks as relative to the sample (expressed in
-        standard deviation from the mean).
+        Only when ``method = "neurokit"``. The minimum interval between the peaks as relative to
+        the sample (expressed in standard deviation from the mean).
     relative_interval_max : float
-        The maximum interval between the peaks as relative to the sample (expressed in
-        standard deviation from the mean).
+        Only when ``method = "neurokit"``. The maximum interval between the peaks as relative to
+        the sample (expressed in standard deviation from the mean).
     robust : bool
-        Use a robust method of standardization (see `standardize()`) for the relative thresholds.
+        Only when ``method = "neurokit"``. Use a robust method of standardization (see
+        `standardize`) for the relative thresholds.
     method : str
-        Either "Kubios" or "Neurokit". "Kubios" uses the artifact detection and correction described
-        in Lipponen, J. A., & Tarvainen, M. P. (2019). Note that "Kubios" is only meant for peaks in
-        ECG or PPG. "neurokit" can be used with peaks in ECG, PPG, or respiratory data.
+        Either ``"Kubios"`` or ``"neurokit"``. ``"Kubios"`` uses the artifact detection and
+        correction described in Lipponen, J. A., & Tarvainen, M. P. (2019). Note that ``"Kubios"``
+        is only meant for peaks in ECG or PPG. ``"neurokit"`` can be used with peaks in ECG, PPG,
+        or respiratory data.
+    **kwargs
+        Other keyword arguments.
 
     Returns
     -------
     peaks_clean : array
         The corrected peak locations.
     artifacts : dict
-        Only if method="Kubios". A dictionary containing the indices of artifacts, accessible with the
-        keys "ectopic", "missed", "extra", and "longshort".
+        Only if ``method="Kubios"``. A dictionary containing the indices of artifacts, accessible
+        with the keys ``"ectopic"``, ``"missed"``, ``"extra"``, and ``"longshort"``.
 
     See Also
     --------
@@ -68,43 +76,68 @@ def signal_fixpeaks(
 
     Examples
     --------
-    >>> import neurokit2 as nk
-    >>> import numpy as np
-    >>> import matplotlib.pyplot as plt
-    >>>
-    >>> # Kubios
-    >>> ecg = nk.ecg_simulate(duration=240, noise=0.25, heart_rate=70, random_state=42)
-    >>> rpeaks_uncorrected = nk.ecg_findpeaks(ecg)
-    >>> artifacts, rpeaks_corrected = nk.signal_fixpeaks(rpeaks_uncorrected, iterative=True,
-    ...                                                  show=True, method="Kubios")
-    >>> rate_corrected = nk.signal_rate(rpeaks_corrected, desired_length=len(ecg))
-    >>> rate_uncorrected = nk.signal_rate(rpeaks_uncorrected, desired_length=len(ecg))
-    >>>
-    >>> fig, ax = plt.subplots()
-    >>> ax.plot(rate_uncorrected, label="heart rate without artifact correction") #doctest: +SKIP
-    >>> ax.plot(rate_corrected, label="heart rate with artifact correction") #doctest: +SKIP
-    >>> ax.legend(loc="upper right") #doctest: +SKIP
-    >>>
-    >>> # NeuroKit
-    >>> signal = nk.signal_simulate(duration=4, sampling_rate=1000, frequency=1)
-    >>> peaks_true = nk.signal_findpeaks(signal)["Peaks"]
-    >>> peaks = np.delete(peaks_true, [1])  # create gaps
-    >>>
-    >>> signal = nk.signal_simulate(duration=20, sampling_rate=1000, frequency=1)
-    >>> peaks_true = nk.signal_findpeaks(signal)["Peaks"]
-    >>> peaks = np.delete(peaks_true, [5, 15])  # create gaps
-    >>> peaks = np.sort(np.append(peaks, [1350, 11350, 18350]))  # add artifacts
-    >>>
-    >>> peaks_corrected = nk.signal_fixpeaks(peaks=peaks, interval_min=0.5, interval_max=1.5, method="neurokit")
-    >>> # Plot and shift original peaks to the rightto see the difference.
-    >>> fig = nk.events_plot([peaks + 50, peaks_corrected], signal)
-    >>> fig #doctest: +SKIP
+    .. ipython:: python
+
+      import neurokit2 as nk
+
+      # Simulate ECG data
+      ecg = nk.ecg_simulate(duration=240, noise=0.25, heart_rate=70, random_state=42)
+
+      # Identify and Correct Peaks using "Kubios" Method
+      rpeaks_uncorrected = nk.ecg_findpeaks(ecg)
+
+      @savefig p_signal_fixpeaks1.png scale=100%
+      artifacts, rpeaks_corrected = nk.signal_fixpeaks(
+          rpeaks_uncorrected, iterative=True, method="Kubios", show=True
+      )
+      @suppress
+      plt.close()
+
+    .. ipython:: python
+
+      # Visualize Artifact Correction
+      rate_corrected = nk.signal_rate(rpeaks_corrected, desired_length=len(ecg))
+      rate_uncorrected = nk.signal_rate(rpeaks_uncorrected, desired_length=len(ecg))
+
+      @savefig p_signal_fixpeaks2.png scale=100%
+      nk.signal_plot(
+          [rate_uncorrected, rate_corrected],
+          labels=["Heart Rate Uncorrected", "Heart Rate Corrected"]
+      )
+      @suppress
+      plt.close()
+
+    .. ipython:: python
+
+      import numpy as np
+
+      # Simulate Abnormal Signals
+      signal = nk.signal_simulate(duration=4, sampling_rate=1000, frequency=1)
+      peaks_true = nk.signal_findpeaks(signal)["Peaks"]
+      peaks = np.delete(peaks_true, [1])  # create gaps due to missing peaks
+
+      signal = nk.signal_simulate(duration=20, sampling_rate=1000, frequency=1)
+      peaks_true = nk.signal_findpeaks(signal)["Peaks"]
+      peaks = np.delete(peaks_true, [5, 15])  # create gaps
+      peaks = np.sort(np.append(peaks, [1350, 11350, 18350]))  # add artifacts
+
+      # Identify and Correct Peaks using 'NeuroKit' Method
+      peaks_corrected = nk.signal_fixpeaks(
+          peaks=peaks, interval_min=0.5, interval_max=1.5, method="neurokit"
+      )
+
+      # Plot and shift original peaks to the right to see the difference.
+      @savefig p_signal_fixpeaks3.png scale=100%
+      nk.events_plot([peaks + 50, peaks_corrected], signal)
+      @suppress
+      plt.close()
+
 
     References
     ----------
-    - Lipponen, J. A., & Tarvainen, M. P. (2019). A robust algorithm for heart rate variability time
-    series artefact correction using novel beat classification. Journal of medical engineering & technology,
-    43(3), 173-181. 10.1080/03091902.2019.1640306
+    * Lipponen, J. A., & Tarvainen, M. P. (2019). A robust algorithm for heart rate variability time
+      series artefact correction using novel beat classification. Journal of medical engineering &
+      technology, 43(3), 173-181. 10.1080/03091902.2019.1640306
 
     """
     # Format input
@@ -112,7 +145,9 @@ def signal_fixpeaks(
 
     # If method Kubios
     if method.lower() == "kubios":
-        return _signal_fixpeaks_kubios(peaks, sampling_rate=sampling_rate, iterative=iterative, show=show)
+        return _signal_fixpeaks_kubios(
+            peaks, sampling_rate=sampling_rate, iterative=iterative, show=show, **kwargs
+        )
     else:
         # Else method is NeuroKit
         return _signal_fixpeaks_neurokit(
@@ -138,19 +173,21 @@ def _signal_fixpeaks_neurokit(
     relative_interval_max=None,
     robust=False,
 ):
-    """Neurokit method."""
+    """NeuroKit method."""
 
     peaks_clean = _remove_small(peaks, sampling_rate, interval_min, relative_interval_min, robust)
-    peaks_clean = _interpolate_big(peaks_clean, sampling_rate, interval_max, relative_interval_max, robust)
+    peaks_clean = _interpolate_big(
+        peaks_clean, sampling_rate, interval_max, relative_interval_max, robust
+    )
 
     return peaks_clean
 
 
-def _signal_fixpeaks_kubios(peaks, sampling_rate=1000, iterative=True, show=False):
+def _signal_fixpeaks_kubios(peaks, sampling_rate=1000, iterative=True, show=False, **kwargs):
     """kubios method."""
 
     # Get corrected peaks and normal-to-normal intervals.
-    artifacts, subspaces = _find_artifacts(peaks, sampling_rate=sampling_rate)
+    artifacts, subspaces = _find_artifacts(peaks, sampling_rate=sampling_rate, **kwargs)
     peaks_clean = _correct_artifacts(artifacts, peaks)
 
     if iterative:
@@ -161,7 +198,9 @@ def _signal_fixpeaks_kubios(peaks, sampling_rate=1000, iterative=True, show=Fals
 
         while True:
 
-            new_artifacts, new_subspaces = _find_artifacts(peaks_clean, sampling_rate=sampling_rate)
+            new_artifacts, new_subspaces = _find_artifacts(
+                peaks_clean, sampling_rate=sampling_rate, **kwargs
+            )
 
             n_artifacts_previous = n_artifacts_current
             n_artifacts_current = sum([len(i) for i in new_artifacts.values()])
@@ -181,7 +220,9 @@ def _signal_fixpeaks_kubios(peaks, sampling_rate=1000, iterative=True, show=Fals
 # =============================================================================
 # Kubios: Lipponen & Tarvainen (2019).
 # =============================================================================
-def _find_artifacts(peaks, c1=0.13, c2=0.17, alpha=5.2, window_width=91, medfilt_order=11, sampling_rate=1000):
+def _find_artifacts(
+    peaks, c1=0.13, c2=0.17, alpha=5.2, window_width=91, medfilt_order=11, sampling_rate=1000
+):
 
     # Compute period series (make sure it has same numer of elements as peaks);
     # peaks are in samples, convert to seconds.
@@ -303,7 +344,12 @@ def _find_artifacts(peaks, c1=0.13, c2=0.17, alpha=5.2, window_width=91, medfilt
             i += 1
 
     # Prepare output
-    artifacts = {"ectopic": ectopic_idcs, "missed": missed_idcs, "extra": extra_idcs, "longshort": longshort_idcs}
+    artifacts = {
+        "ectopic": ectopic_idcs,
+        "missed": missed_idcs,
+        "extra": extra_idcs,
+        "longshort": longshort_idcs,
+    }
 
     subspaces = {"rr": rr, "drrs": drrs, "mrrs": mrrs, "s12": s12, "s22": s22, "c1": c1, "c2": c2}
 
@@ -372,7 +418,9 @@ def _correct_missed(missed_idcs, peaks):
     # Calculate the position(s) of new beat(s). Make sure to not generate
     # negative indices. prev_peaks and next_peaks must have the same
     # number of elements.
-    valid_idcs = np.logical_and(missed_idcs > 1, missed_idcs < len(corrected_peaks))  # pylint: disable=E1111
+    valid_idcs = np.logical_and(
+        missed_idcs > 1, missed_idcs < len(corrected_peaks)
+    )  # pylint: disable=E1111
     missed_idcs = missed_idcs[valid_idcs]
     prev_peaks = corrected_peaks[[i - 1 for i in missed_idcs]]
     next_peaks = corrected_peaks[missed_idcs]
@@ -448,10 +496,16 @@ def _plot_artifacts_lipponen2019(artifacts, info):
 
     ax0.set_title("Artifact types", fontweight="bold")
     ax0.plot(rr, label="heart period")
-    ax0.scatter(longshort_idcs, rr[longshort_idcs], marker="x", c="m", s=100, zorder=3, label="long/short")
+    ax0.scatter(
+        longshort_idcs, rr[longshort_idcs], marker="x", c="m", s=100, zorder=3, label="long/short"
+    )
     ax0.scatter(ectopic_idcs, rr[ectopic_idcs], marker="x", c="g", s=100, zorder=3, label="ectopic")
-    ax0.scatter(extra_idcs, rr[extra_idcs], marker="x", c="y", s=100, zorder=3, label="false positive")
-    ax0.scatter(missed_idcs, rr[missed_idcs], marker="x", c="r", s=100, zorder=3, label="false negative")
+    ax0.scatter(
+        extra_idcs, rr[extra_idcs], marker="x", c="y", s=100, zorder=3, label="false positive"
+    )
+    ax0.scatter(
+        missed_idcs, rr[missed_idcs], marker="x", c="r", s=100, zorder=3, label="false negative"
+    )
     ax0.legend(loc="upper right")
 
     # Visualize first threshold.
@@ -477,7 +531,9 @@ def _plot_artifacts_lipponen2019(artifacts, info):
     ax4.set_xlim(-10, 10)
     verts0 = [(-10, 5), (-10, -c1 * -10 + c2), (-1, -c1 * -1 + c2), (-1, 5)]
 
-    poly0 = matplotlib.patches.Polygon(verts0, alpha=0.3, facecolor="r", edgecolor=None, label="ectopic periods")
+    poly0 = matplotlib.patches.Polygon(
+        verts0, alpha=0.3, facecolor="r", edgecolor=None, label="ectopic periods"
+    )
     ax4.add_patch(poly0)
     verts1 = [(1, -c1 * 1 - c2), (1, -5), (10, -5), (10, -c1 * 10 - c2)]
     poly1 = matplotlib.patches.Polygon(verts1, alpha=0.3, facecolor="r", edgecolor=None)
@@ -491,18 +547,24 @@ def _plot_artifacts_lipponen2019(artifacts, info):
     ax3.set_xlim(-10, 10)
     ax3.set_ylim(-10, 10)
     verts2 = [(-10, 10), (-10, 1), (-1, 1), (-1, 10)]
-    poly2 = matplotlib.patches.Polygon(verts2, alpha=0.3, facecolor="r", edgecolor=None, label="short periods")
+    poly2 = matplotlib.patches.Polygon(
+        verts2, alpha=0.3, facecolor="r", edgecolor=None, label="short periods"
+    )
     ax3.add_patch(poly2)
     verts3 = [(1, -1), (1, -10), (10, -10), (10, -1)]
-    poly3 = matplotlib.patches.Polygon(verts3, alpha=0.3, facecolor="y", edgecolor=None, label="long periods")
+    poly3 = matplotlib.patches.Polygon(
+        verts3, alpha=0.3, facecolor="y", edgecolor=None, label="long periods"
+    )
     ax3.add_patch(poly3)
     ax3.legend(loc="upper right")
 
 
 # =============================================================================
-# Neurokit
+# NeuroKit
 # =============================================================================
-def _remove_small(peaks, sampling_rate=1000, interval_min=None, relative_interval_min=None, robust=False):
+def _remove_small(
+    peaks, sampling_rate=1000, interval_min=None, relative_interval_min=None, robust=False
+):
     if interval_min is None and relative_interval_min is None:
         return peaks
 
@@ -517,7 +579,9 @@ def _remove_small(peaks, sampling_rate=1000, interval_min=None, relative_interva
     return peaks
 
 
-def _interpolate_big(peaks, sampling_rate=1000, interval_max=None, relative_interval_max=None, robust=False):
+def _interpolate_big(
+    peaks, sampling_rate=1000, interval_max=None, relative_interval_max=None, robust=False
+):
     if interval_max is None and relative_interval_max is None:
         return peaks
 
@@ -525,12 +589,16 @@ def _interpolate_big(peaks, sampling_rate=1000, interval_max=None, relative_inte
     while continue_loop is True:
         if interval_max is not None:
             interval = signal_period(peaks, sampling_rate=sampling_rate, desired_length=None)
-            peaks, continue_loop = _interpolate_missing(peaks, interval, interval_max, sampling_rate)
+            peaks, continue_loop = _interpolate_missing(
+                peaks, interval, interval_max, sampling_rate
+            )
 
         if relative_interval_max is not None:
             interval = signal_period(peaks, sampling_rate=sampling_rate, desired_length=None)
             interval = standardize(interval, robust=robust)
-            peaks, continue_loop = _interpolate_missing(peaks, interval, relative_interval_max, sampling_rate)
+            peaks, continue_loop = _interpolate_missing(
+                peaks, interval, relative_interval_max, sampling_rate
+            )
 
     return peaks
 
@@ -549,7 +617,9 @@ def _interpolate_missing(peaks, interval, interval_max, sampling_rate):
     # Interpolate values
     interval = pd.Series(interval).interpolate().values
     peaks_corrected = _period_to_location(interval, sampling_rate, first_location=peaks[0])
-    peaks = np.insert(peaks, outliers_loc, peaks_corrected[outliers_loc + np.arange(len(outliers_loc))])
+    peaks = np.insert(
+        peaks, outliers_loc, peaks_corrected[outliers_loc + np.arange(len(outliers_loc))]
+    )
     return peaks, True
 
 
