@@ -7,16 +7,17 @@ import scipy.signal
 def signal_synchrony(signal1, signal2, method="hilbert", window_size=50):
     """Compute the synchrony (coupling) between two signals.
 
-    Compute a continuous index of coupling between two signals either using the 'Hilbert' method to get
-    the instantaneous phase synchrony, or using rolling window correlation.
+    Compute a continuous index of coupling between two signals either using the ``"hilbert"``
+    method to get the instantaneous phase synchrony, or using rolling window correlation.
 
-    The instantaneous phase synchrony measures the phase similarities between signals at each timepoint.
-    The phase refers to the angle of the signal, calculated through the hilbert transform, when it is
-    resonating between -pi to pi degrees. When two signals line up in phase their angular difference becomes zero.
-
-    For less clean signals, windowed correlations are widely used because of their simplicity, and can
-    be a good a robust approximation of synchrony between two signals. The limitation is the need to select a window.
+    The instantaneous phase synchrony measures the phase similarities between signals at each
+    timepoint. The phase refers to the angle of the signal, calculated through the hilbert
+    transform, when it is resonating between -pi to pi degrees. When two signals line up in phase
+    their angular difference becomes zero.
 
+    For less clean signals, windowed correlations are widely used because of their simplicity, and
+    can be a good a robust approximation of synchrony between two signals. The limitation is the
+    need to select a window.
 
 
     Parameters
@@ -26,9 +27,9 @@ def signal_synchrony(signal1, signal2, method="hilbert", window_size=50):
     signal2 : Union[list, np.array, pd.Series]
         Time series in the form of a vector of values.
     method : str
-        The method to use. Can be one of 'hilbert' or 'correlation'.
+        The method to use. Can be one of ``"hilbert"`` or ``"correlation"``.
     window_size : int
-        Only used if `method='correlation'`. The number of samples to use for rolling correlation.
+        Only used if ``method='correlation'``. The number of samples to use for rolling correlation.
 
     See Also
     --------
@@ -41,20 +42,24 @@ def signal_synchrony(signal1, signal2, method="hilbert", window_size=50):
 
     Examples
     --------
-    >>> import neurokit2 as nk
-    >>>
-    >>> signal1 = nk.signal_simulate(duration=10, frequency=1)
-    >>> signal2 = nk.signal_simulate(duration=10, frequency=1.5)
-    >>>
-    >>> coupling_h = nk.signal_synchrony(signal1, signal2, method="hilbert")
-    >>> coupling_c = nk.signal_synchrony(signal1, signal2, method="correlation", window_size=1000/2)
-    >>>
-    >>> fig = nk.signal_plot([signal1, signal2, coupling_h, coupling_c])
-    >>> fig #doctest: +SKIP
+    .. ipython:: python
+
+      import neurokit2 as nk
+
+      signal1 = nk.signal_simulate(duration=10, frequency=1)
+      signal2 = nk.signal_simulate(duration=10, frequency=1.5)
+
+      coupling_h = nk.signal_synchrony(signal1, signal2, method="hilbert")
+      coupling_c = nk.signal_synchrony(signal1, signal2, method="correlation", window_size=1000/2)
+
+      @savefig p_signal_synchrony1.png scale=100%
+      nk.signal_plot([signal1, signal2, coupling_h, coupling_c])
+      @suppress
+      plt.close()
 
     References
     ----------
-    -  http://jinhyuncheong.com/jekyll/update/2017/12/10/Timeseries_synchrony_tutorial_and_simulations.html
+    *  http://jinhyuncheong.com/jekyll/update/2017/12/10/Timeseries_synchrony_tutorial_and_simulations.html
 
     """
     if method.lower() in ["hilbert", "phase"]:
@@ -63,7 +68,9 @@ def signal_synchrony(signal1, signal2, method="hilbert", window_size=50):
         coupling = _signal_synchrony_correlation(signal1, signal2, window_size=int(window_size))
 
     else:
-        raise ValueError("NeuroKit error: signal_synchrony(): 'method' should be one of 'hilbert' or 'correlation'.")
+        raise ValueError(
+            "NeuroKit error: signal_synchrony(): 'method' should be one of 'hilbert' or 'correlation'."
+        )
 
     return coupling
 
@@ -86,10 +93,12 @@ def _signal_synchrony_hilbert(signal1, signal2):
 
 
 def _signal_synchrony_correlation(signal1, signal2, window_size, center=False):
-    """Calculates pairwise rolling correlation at each time. Grabs the upper triangle, at each timepoints.
+    """**Calculates pairwise rolling correlation at each time**
+    Grabs the upper triangle, at each timepoint.
 
-    - window: window size of rolling corr in samples
-    - center: whether to center result (Default: False, so correlation values are listed on the right.)
+    * window: window size of rolling corr in samples
+    * center: whether to center result (Default: False, so correlation values are listed on the
+      right.)
 
     """
     data = pd.DataFrame({"y1": signal1, "y2": signal2})
