@@ -1,36 +1,51 @@
 # -*- coding: utf-8 -*-
-import warnings
 import functools
+import warnings
+
 import numpy as np
 import pandas as pd
-import sklearn.cluster
-import sklearn.mixture
-import sklearn.decomposition
-import scipy.spatial
 import scipy.linalg
+import scipy.spatial
+import sklearn.cluster
+import sklearn.decomposition
+import sklearn.mixture
 
 from .cluster_quality import _cluster_quality_distance
 
+
 def cluster(data, method="kmeans", n_clusters=2, random_state=None, optimize=False, **kwargs):
-    """Performs clustering of data according to different algorithms.
+    """**Data Clustering**
+
+    Performs clustering of data using different algorithms.
+
+    * **kmod**: Modified k-means algorithm.
+    * **kmeans**: Normal k-means.
+    * **kmedoids**: k-medoids clustering, a more stable version of k-means.
+    * **pca**: Principal Component Analysis.
+    * **ica**: Independent Component Analysis.
+    * **aahc**: Atomize and Agglomerate Hierarchical Clustering. Computationally heavy.
+    * **hierarchical**
+    * **spectral**
+    * **mixture**
+    * **mixturebayesian**
+
+    See ``sklearn`` for methods details.
 
     Parameters
     ----------
     data : np.ndarray
         Matrix array of data (E.g., an array (channels, times) of M/EEG data).
     method : str
-        The algorithm for clustering. Can be one of 'kmeans' (default), modified k-means algorithm 'kmod',
-        'kmedoids' (k-centers or k-medoids clustering), 'pca' (Principal Component Analysis), 'ica' (Independent Component
-        Analysis), 'agglomerative' (Atomize and Agglomerate Hierarchical Clustering), 'hierarchical', 'spectral',
-        'mixture', 'mixturebayesian'. See ``sklearn`` for methods details.
+        The algorithm for clustering. Can be one of ``"kmeans"`` (default), ``"kmod"``,
+        ``"kmedoids"``, ``"pca"``, ``"ica"``, ``"aahc"``, ``"hierarchical"``, ``"spectral"``,
+        ``"mixture"``, ``"mixturebayesian"``.
     n_clusters : int
         The desired number of clusters.
     random_state : Union[int, numpy.random.RandomState]
         The ``RandomState`` for the random number generator. Defaults to ``None``, in which case a
         different random state is chosen each time this function is called.
     optimize : bool
-        To use a new optimized method in https://www.biorxiv.org/content/10.1101/289850v1.full.pdf.
-        For the Kmeans modified method. Default to False.
+        Optimized method in Poulsen et al. (2018) for the *k*-means modified method.
     **kwargs
         Other arguments to be passed into ``sklearn`` functions.
 
@@ -45,62 +60,67 @@ def cluster(data, method="kmeans", n_clusters=2, random_state=None, optimize=Fal
 
     Examples
     ----------
-    >>> import neurokit2 as nk
-    >>> import matplotlib.pyplot as plt
-    >>>
-    >>> # Load the iris dataset
-    >>> data = nk.data("iris")
-    >>>
-    >>> # Cluster using different methods
-    >>> clustering_kmeans, clusters_kmeans, info = nk.cluster(data, method="kmeans", n_clusters=3)
-    >>> clustering_spectral, clusters_spectral, info = nk.cluster(data, method="spectral", n_clusters=3)
-    >>> clustering_hierarchical, clusters_hierarchical, info = nk.cluster(data, method="hierarchical", n_clusters=3)
-    >>> clustering_agglomerative, clusters_agglomerative, info= nk.cluster(data, method="agglomerative", n_clusters=3)
-    >>> clustering_mixture, clusters_mixture, info = nk.cluster(data, method="mixture", n_clusters=3)
-    >>> clustering_bayes, clusters_bayes, info = nk.cluster(data, method="mixturebayesian", n_clusters=3)
-    >>> clustering_pca, clusters_pca, info = nk.cluster(data, method="pca", n_clusters=3)
-    >>> clustering_ica, clusters_ica, info = nk.cluster(data, method="ica", n_clusters=3)
-    >>> clustering_kmod, clusters_kmod, info = nk.cluster(data, method="kmod", n_clusters=3)
-    >>> clustering_kmedoids, clusters_kmedoids, info = nk.cluster(data, method="kmedoids", n_clusters=3)
-    >>> clustering_aahc, clusters_aahc, info = nk.cluster(data, method='aahc_frederic', n_clusters=3)
-    >>>
-    >>> # Visualize classification and 'average cluster'
-    >> fig, axes = plt.subplots(ncols=2, nrows=5)
-    >> axes[0, 0].scatter(data.iloc[:,[2]], data.iloc[:,[3]], c=clustering_kmeans['Cluster'])
-    >> axes[0, 0].scatter(clusters_kmeans[:, 2], clusters_kmeans[:, 3], c='red')
-    >> axes[0, 0].set_title("k-means")
-    >> axes[0, 1].scatter(data.iloc[:,[2]], data.iloc[:, [3]], c=clustering_spectral['Cluster'])
-    >> axes[0, 1].scatter(clusters_spectral[:, 2], clusters_spectral[:, 3], c='red')
-    >> axes[0, 1].set_title("Spectral")
-    >> axes[1, 0].scatter(data.iloc[:,[2]], data.iloc[:,[3]], c=clustering_hierarchical['Cluster'])
-    >> axes[1, 0].scatter(clusters_hierarchical[:, 2], clusters_hierarchical[:, 3], c='red')
-    >> axes[1, 0].set_title("Hierarchical")
-    >> axes[1, 1].scatter(data.iloc[:,[2]], data.iloc[:,[3]], c=clustering_agglomerative['Cluster'])
-    >> axes[1, 1].scatter(clusters_agglomerative[:, 2], clusters_agglomerative[:, 3], c='red')
-    >> axes[1, 1].set_title("Agglomerative")
-    >> axes[2, 0].scatter(data.iloc[:,[2]], data.iloc[:,[3]], c=clustering_mixture['Cluster'])
-    >> axes[2, 0].scatter(clusters_mixture[:, 2], clusters_mixture[:, 3], c='red')
-    >> axes[2, 0].set_title("Mixture")
-    >> axes[2, 1].scatter(data.iloc[:,[2]], data.iloc[:,[3]], c=clustering_bayes['Cluster'])
-    >> axes[2, 1].scatter(clusters_bayes[:, 2], clusters_bayes[:, 3], c='red')
-    >> axes[2, 1].set_title("Bayesian Mixture")
-    >> axes[3, 0].scatter(data.iloc[:,[2]], data.iloc[:,[3]], c=clustering_pca['Cluster'])
-    >> axes[3, 0].scatter(clusters_pca[:, 2], clusters_pca[:, 3], c='red')
-    >> axes[3, 0].set_title("PCA")
-    >> axes[3, 1].scatter(data.iloc[:,[2]], data.iloc[:,[3]], c=clustering_ica['Cluster'])
-    >> axes[3, 1].scatter(clusters_ica[:, 2], clusters_ica[:, 3], c='red')
-    >> axes[3, 1].set_title("ICA")
-    >> axes[4, 0].scatter(data.iloc[:,[2]], data.iloc[:,[3]], c=clustering_kmod['Cluster'])
-    >> axes[4, 0].scatter(clusters_kmod[:, 2], clusters_kmod[:, 3], c='red')
-    >> axes[4, 0].set_title("modified K-means")
-    >> axes[4, 1].scatter(data.iloc[:,[2]], data.iloc[:,[3]], c=clustering_aahc['Cluster'])
-    >> axes[4, 1].scatter(clusters_aahc[:, 2], clusters_aahc[:, 3], c='red')
-    >> axes[4, 1].set_title("AAHC (Frederic's method)")
+    .. ipython:: python
 
-    Refereneces
+      import neurokit2 as nk
+      import matplotlib.pyplot as plt
+
+      # Load the iris dataset
+      data = nk.data("iris").drop("Species", axis=1)
+
+      # Cluster using different methods
+      clustering_kmeans, clusters_kmeans, info = nk.cluster(data, method="kmeans", n_clusters=3)
+      clustering_spectral, clusters_spectral, info = nk.cluster(data, method="spectral", n_clusters=3)
+      clustering_hierarchical, clusters_hierarchical, info = nk.cluster(data, method="hierarchical", n_clusters=3)
+      clustering_agglomerative, clusters_agglomerative, info= nk.cluster(data, method="agglomerative", n_clusters=3)
+      clustering_mixture, clusters_mixture, info = nk.cluster(data, method="mixture", n_clusters=3)
+      clustering_bayes, clusters_bayes, info = nk.cluster(data, method="mixturebayesian", n_clusters=3)
+      clustering_pca, clusters_pca, info = nk.cluster(data, method="pca", n_clusters=3)
+      clustering_ica, clusters_ica, info = nk.cluster(data, method="ica", n_clusters=3)
+      clustering_kmod, clusters_kmod, info = nk.cluster(data, method="kmod", n_clusters=3)
+      clustering_kmedoids, clusters_kmedoids, info = nk.cluster(data, method="kmedoids", n_clusters=3)
+      clustering_aahc, clusters_aahc, info = nk.cluster(data, method='aahc_frederic', n_clusters=3)
+
+      # Visualize classification and 'average cluster'
+      @savefig p_cluster1.png scale=100%
+      fig, axes = plt.subplots(ncols=2, nrows=5)
+      axes[0, 0].scatter(data.iloc[:,[2]], data.iloc[:,[3]], c=clustering_kmeans['Cluster'])
+      axes[0, 0].scatter(clusters_kmeans[:, 2], clusters_kmeans[:, 3], c='red')
+      axes[0, 0].set_title("k-means")
+      axes[0, 1].scatter(data.iloc[:,[2]], data.iloc[:, [3]], c=clustering_spectral['Cluster'])
+      axes[0, 1].scatter(clusters_spectral[:, 2], clusters_spectral[:, 3], c='red')
+      axes[0, 1].set_title("Spectral")
+      axes[1, 0].scatter(data.iloc[:,[2]], data.iloc[:,[3]], c=clustering_hierarchical['Cluster'])
+      axes[1, 0].scatter(clusters_hierarchical[:, 2], clusters_hierarchical[:, 3], c='red')
+      axes[1, 0].set_title("Hierarchical")
+      axes[1, 1].scatter(data.iloc[:,[2]], data.iloc[:,[3]], c=clustering_agglomerative['Cluster'])
+      axes[1, 1].scatter(clusters_agglomerative[:, 2], clusters_agglomerative[:, 3], c='red')
+      axes[1, 1].set_title("Agglomerative")
+      axes[2, 0].scatter(data.iloc[:,[2]], data.iloc[:,[3]], c=clustering_mixture['Cluster'])
+      axes[2, 0].scatter(clusters_mixture[:, 2], clusters_mixture[:, 3], c='red')
+      axes[2, 0].set_title("Mixture")
+      axes[2, 1].scatter(data.iloc[:,[2]], data.iloc[:,[3]], c=clustering_bayes['Cluster'])
+      axes[2, 1].scatter(clusters_bayes[:, 2], clusters_bayes[:, 3], c='red')
+      axes[2, 1].set_title("Bayesian Mixture")
+      axes[3, 0].scatter(data.iloc[:,[2]], data.iloc[:,[3]], c=clustering_pca['Cluster'])
+      axes[3, 0].scatter(clusters_pca[:, 2], clusters_pca[:, 3], c='red')
+      axes[3, 0].set_title("PCA")
+      axes[3, 1].scatter(data.iloc[:,[2]], data.iloc[:,[3]], c=clustering_ica['Cluster'])
+      axes[3, 1].scatter(clusters_ica[:, 2], clusters_ica[:, 3], c='red')
+      axes[3, 1].set_title("ICA")
+      axes[4, 0].scatter(data.iloc[:,[2]], data.iloc[:,[3]], c=clustering_kmod['Cluster'])
+      axes[4, 0].scatter(clusters_kmod[:, 2], clusters_kmod[:, 3], c='red')
+      axes[4, 0].set_title("modified K-means")
+      axes[4, 1].scatter(data.iloc[:,[2]], data.iloc[:,[3]], c=clustering_aahc['Cluster'])
+      axes[4, 1].scatter(clusters_aahc[:, 2], clusters_aahc[:, 3], c='red')
+      axes[4, 1].set_title("AAHC (Frederic's method)")
+      @suppress
+      plt.close()
+
+    References
     -----------
-    - Park, H. S., & Jun, C. H. (2009). A simple and fast algorithm for K-medoids
-    clustering. Expert systems with applications, 36(2), 3336-3341.
+    * Park, H. S., & Jun, C. H. (2009). A simple and fast algorithm for K-medoids
+      clustering. Expert systems with applications, 36(2), 3336-3341.
 
     """
     # Sanity checks
@@ -110,19 +130,16 @@ def cluster(data, method="kmeans", n_clusters=2, random_state=None, optimize=Fal
     method = method.lower()
     # K-means
     if method in ["kmeans", "k", "k-means", "kmean"]:
-        out = _cluster_kmeans(data,
-                              n_clusters=n_clusters,
-                              random_state=random_state,
-                              **kwargs)
+        out = _cluster_kmeans(data, n_clusters=n_clusters, random_state=random_state, **kwargs)
 
     # Modified k-means
     elif method in ["kmods", "kmod", "kmeans modified", "modified kmeans"]:
-        out = _cluster_kmod(data, n_clusters=n_clusters,
-                            random_state=random_state, optimize=optimize, **kwargs)
+        out = _cluster_kmod(
+            data, n_clusters=n_clusters, random_state=random_state, optimize=optimize, **kwargs
+        )
     # K-medoids
     elif method in ["kmedoids", "k-medoids", "k-centers"]:
-        out = _cluster_kmedoids(data, n_clusters=n_clusters,
-                                random_state=random_state, **kwargs)
+        out = _cluster_kmedoids(data, n_clusters=n_clusters, random_state=random_state, **kwargs)
 
     # PCA
     elif method in ["pca", "principal", "principal component analysis"]:
@@ -134,32 +151,23 @@ def cluster(data, method="kmeans", n_clusters=2, random_state=None, optimize=Fal
 
     # Mixture
     elif method in ["mixture", "mixt"]:
-        out = _cluster_mixture(data,
-                               n_clusters=n_clusters,
-                               bayesian=False,
-                               random_state=random_state,
-                               **kwargs)
+        out = _cluster_mixture(
+            data, n_clusters=n_clusters, bayesian=False, random_state=random_state, **kwargs
+        )
 
     # Frederic's AAHC
     elif method in ["aahc_frederic", "aahc_eegmicrostates"]:
-        out = _cluster_aahc(data,
-                            n_clusters=n_clusters,
-                            random_state=random_state,
-                            **kwargs)
+        out = _cluster_aahc(data, n_clusters=n_clusters, random_state=random_state, **kwargs)
 
     # Bayesian
     elif method in ["bayesianmixture", "bayesmixt", "mixturebayesian", "mixturebayes"]:
-        out = _cluster_mixture(data,
-                               n_clusters=n_clusters,
-                               bayesian=True,
-                               random_state=random_state,
-                               **kwargs)
+        out = _cluster_mixture(
+            data, n_clusters=n_clusters, bayesian=True, random_state=random_state, **kwargs
+        )
 
     # Others
     else:
-        out = _cluster_sklearn(data,
-                               n_clusters=n_clusters,
-                               **kwargs)
+        out = _cluster_sklearn(data, n_clusters=n_clusters, **kwargs)
 
     return out
 
@@ -175,12 +183,11 @@ def cluster(data, method="kmeans", n_clusters=2, random_state=None, optimize=Fal
 # Kmeans
 # =============================================================================
 def _cluster_kmeans(data, n_clusters=2, random_state=None, **kwargs):
-    """K-means clustering algorithm
-    """
+    """K-means clustering algorithm"""
     # Initialize clustering function
-    clustering_model = sklearn.cluster.KMeans(n_clusters=n_clusters,
-                                              random_state=random_state,
-                                              **kwargs)
+    clustering_model = sklearn.cluster.KMeans(
+        n_clusters=n_clusters, random_state=random_state, **kwargs
+    )
 
     # Fit
     clustering = clustering_model.fit_predict(data)
@@ -194,16 +201,17 @@ def _cluster_kmeans(data, n_clusters=2, random_state=None, **kwargs):
     prediction["Cluster"] = clustering
 
     # Copy function with given parameters
-    clustering_function = functools.partial(_cluster_kmeans,
-                                            n_clusters=n_clusters,
-                                            random_state=random_state,
-                                            **kwargs)
+    clustering_function = functools.partial(
+        _cluster_kmeans, n_clusters=n_clusters, random_state=random_state, **kwargs
+    )
 
     # Info dump
-    info = {"n_clusters": n_clusters,
-            "clustering_function": clustering_function,
-            "sklearn_model": clustering_model,
-            "random_state": random_state}
+    info = {
+        "n_clusters": n_clusters,
+        "clustering_function": clustering_function,
+        "sklearn_model": clustering_model,
+        "random_state": random_state,
+    }
 
     return prediction, clusters, info
 
@@ -212,12 +220,13 @@ def _cluster_kmeans(data, n_clusters=2, random_state=None, **kwargs):
 # K-medoids
 # =============================================================================
 
+
 def _cluster_kmedoids(data, n_clusters=2, max_iterations=1000, random_state=None, **kwargs):
     """Peforms k-medoids clustering which is based on the most centrally located object in a cluster.
     Less sensitive to outliers than K-means clustering.
 
     Adapted from https://github.com/rakeshvar/kmedoids/. Original proposed algorithm from Park & Jun (2009).
-   """
+    """
     # Sanitize
     if isinstance(data, pd.DataFrame):
         data = np.array(data)
@@ -229,10 +238,10 @@ def _cluster_kmedoids(data, n_clusters=2, max_iterations=1000, random_state=None
     ids_of_medoids = np.random.choice(n_samples, n_clusters, replace=False)
 
     # Find distance between objects to their medoids, can be euclidean or manhatten
-    def find_distance(x, y, dist_method='euclidean'):
-        if dist_method == 'euclidean':
+    def find_distance(x, y, dist_method="euclidean"):
+        if dist_method == "euclidean":
             return np.sqrt(np.sum(np.square(x - y), axis=-1))
-        elif dist_method == 'manhatten':
+        elif dist_method == "manhatten":
             return np.sum(np.abs(x - y), axis=-1)
 
     individual_points = data[:, None, :]
@@ -272,16 +281,20 @@ def _cluster_kmedoids(data, n_clusters=2, max_iterations=1000, random_state=None
     prediction["Cluster"] = segmentation
 
     # Copy function with given parameters
-    clustering_function = functools.partial(_cluster_kmedoids,
-                                            n_clusters=n_clusters,
-                                            max_iterations=max_iterations,
-                                            random_state=random_state)
+    clustering_function = functools.partial(
+        _cluster_kmedoids,
+        n_clusters=n_clusters,
+        max_iterations=max_iterations,
+        random_state=random_state,
+    )
 
     # Info dump
-    info = {"n_clusters": n_clusters,
-            "clustering_function": clustering_function,
-            "random_state": random_state,
-            "clusters": clusters}
+    info = {
+        "n_clusters": n_clusters,
+        "clustering_function": clustering_function,
+        "random_state": random_state,
+        "clusters": clusters,
+    }
 
     return prediction, clusters, info
 
@@ -289,8 +302,15 @@ def _cluster_kmedoids(data, n_clusters=2, max_iterations=1000, random_state=None
 # =============================================================================
 # Modified K-means
 # =============================================================================
-def _cluster_kmod(data, n_clusters=4, max_iterations=1000, threshold=1e-6, random_state=None,
-                  optimize=False, **kwargs):
+def _cluster_kmod(
+    data,
+    n_clusters=4,
+    max_iterations=1000,
+    threshold=1e-6,
+    random_state=None,
+    optimize=False,
+    **kwargs
+):
     """The modified K-means clustering algorithm,
 
     adapted from Marijn van Vliet and Frederic von Wegner.
@@ -344,7 +364,6 @@ def _cluster_kmod(data, n_clusters=4, max_iterations=1000, threshold=1e-6, rando
     # Normalize row-wise (across EEG channels)
     clusters /= np.linalg.norm(clusters, axis=1, keepdims=True)  # Normalize the maps
 
-
     # Initialize iteration
     prev_residual = 0
     for i in range(max_iterations):
@@ -358,7 +377,7 @@ def _cluster_kmod(data, n_clusters=4, max_iterations=1000, threshold=1e-6, rando
         for state in np.arange(n_clusters):
 
             # Get data fro specific state
-            idx = (segmentation == state)
+            idx = segmentation == state
             data_state = data[idx, :]
 
             # Sanity check
@@ -395,8 +414,10 @@ def _cluster_kmod(data, n_clusters=4, max_iterations=1000, threshold=1e-6, rando
         prev_residual = residual.copy()
 
     if i == max_iterations:
-        warnings.warn("Modified K-means algorithm failed to converge after " + str(i) + "",
-                      "iterations. Consider increasing 'max_iterations'.")
+        warnings.warn(
+            "Modified K-means algorithm failed to converge after " + str(i) + "",
+            "iterations. Consider increasing 'max_iterations'.",
+        )
 
     # De-normalize
     clusters_unnormalized = _cluster_getclusters(data, segmentation)
@@ -404,63 +425,70 @@ def _cluster_kmod(data, n_clusters=4, max_iterations=1000, threshold=1e-6, rando
     prediction["Cluster"] = segmentation
 
     # Copy function with given parameters
-    clustering_function = functools.partial(_cluster_kmod,
-                                            n_clusters=n_clusters,
-                                            max_iterations=max_iterations,
-                                            threshold=threshold,
-                                            random_state=random_state,
-                                            **kwargs)
+    clustering_function = functools.partial(
+        _cluster_kmod,
+        n_clusters=n_clusters,
+        max_iterations=max_iterations,
+        threshold=threshold,
+        random_state=random_state,
+        **kwargs
+    )
 
     # Info dump
-    info = {"n_clusters": n_clusters,
-            "clustering_function": clustering_function,
-            "random_state": random_state,
-            "clusters_normalized": clusters,
-            "residual": residual}
+    info = {
+        "n_clusters": n_clusters,
+        "clustering_function": clustering_function,
+        "random_state": random_state,
+        "clusters_normalized": clusters,
+        "residual": residual,
+    }
 
     return prediction, clusters_unnormalized, info
 
 
-
 # =============================================================================
 # PCA
 # =============================================================================
 def _cluster_pca(data, n_clusters=2, random_state=None, **kwargs):
-    """Principal Component Analysis (PCA) for clustering.
-    """
+    """Principal Component Analysis (PCA) for clustering."""
     # Fit PCA
-    pca = sklearn.decomposition.PCA(n_components=n_clusters,
-                                    copy=True,
-                                    whiten=True,
-                                    svd_solver='auto',
-                                    random_state=random_state,
-                                    **kwargs)
+    pca = sklearn.decomposition.PCA(
+        n_components=n_clusters,
+        copy=True,
+        whiten=True,
+        svd_solver="auto",
+        random_state=random_state,
+        **kwargs
+    )
     pca = pca.fit(data)
     # clusters = np.array([pca.components_[state, :] for state in range(n_clusters)])
 
     # Compute variance explained
-#    explained_var = pca.explained_variance_ratio_
-#    total_explained_var = np.sum(pca.explained_variance_ratio_)
+    #    explained_var = pca.explained_variance_ratio_
+    #    total_explained_var = np.sum(pca.explained_variance_ratio_)
 
     # Get distance
     prediction = pca.transform(data)
     prediction = pd.DataFrame(prediction).add_prefix("Loading_")
     prediction["Cluster"] = prediction.abs().idxmax(axis=1).values
-    prediction["Cluster"] = [np.where(prediction.columns == state)[0][0] for state in prediction["Cluster"]]
+    prediction["Cluster"] = [
+        np.where(prediction.columns == state)[0][0] for state in prediction["Cluster"]
+    ]
 
     # Recover states from clustering
     clusters = _cluster_getclusters(data, prediction["Cluster"])
 
     # Copy function with given parameters
-    clustering_function = functools.partial(_cluster_pca,
-                                            n_clusters=n_clusters,
-                                            random_state=random_state,
-                                            **kwargs)
+    clustering_function = functools.partial(
+        _cluster_pca, n_clusters=n_clusters, random_state=random_state, **kwargs
+    )
 
     # Info dump
-    info = {"n_clusters": n_clusters,
-            "clustering_function": clustering_function,
-            "random_state": random_state}
+    info = {
+        "n_clusters": n_clusters,
+        "clustering_function": clustering_function,
+        "random_state": random_state,
+    }
 
     return prediction, clusters, info
 
@@ -469,38 +497,42 @@ def _cluster_pca(data, n_clusters=2, random_state=None, **kwargs):
 # ICA
 # =============================================================================
 def _cluster_ica(data, n_clusters=2, random_state=None, **kwargs):
-    """Independent Component Analysis (ICA) for clustering.
-    """
+    """Independent Component Analysis (ICA) for clustering."""
     # Fit ICA
-    ica = sklearn.decomposition.FastICA(n_components=n_clusters,
-                                        algorithm='parallel',
-                                        whiten=True,
-                                        fun='exp',
-                                        random_state=random_state,
-                                        **kwargs)
+    ica = sklearn.decomposition.FastICA(
+        n_components=n_clusters,
+        algorithm="parallel",
+        whiten=True,
+        fun="exp",
+        random_state=random_state,
+        **kwargs
+    )
 
     ica = ica.fit(data)
-#    clusters = np.array([ica.components_[state, :] for state in range(n_clusters)])
+    #    clusters = np.array([ica.components_[state, :] for state in range(n_clusters)])
 
     # Get distance
     prediction = ica.transform(data)
     prediction = pd.DataFrame(prediction).add_prefix("Loading_")
     prediction["Cluster"] = prediction.abs().idxmax(axis=1).values
-    prediction["Cluster"] = [np.where(prediction.columns == state)[0][0] for state in prediction["Cluster"]]
+    prediction["Cluster"] = [
+        np.where(prediction.columns == state)[0][0] for state in prediction["Cluster"]
+    ]
 
     # Copy function with given parameters
-    clustering_function = functools.partial(_cluster_ica,
-                                            n_clusters=n_clusters,
-                                            random_state=random_state,
-                                            **kwargs)
+    clustering_function = functools.partial(
+        _cluster_ica, n_clusters=n_clusters, random_state=random_state, **kwargs
+    )
 
     # Recover states from clustering
     clusters = _cluster_getclusters(data, prediction["Cluster"])
 
     # Info dump
-    info = {"n_clusters": n_clusters,
-            "clustering_function": clustering_function,
-            "random_state": random_state}
+    info = {
+        "n_clusters": n_clusters,
+        "clustering_function": clustering_function,
+        "random_state": random_state,
+    }
 
     return prediction, clusters, info
 
@@ -509,15 +541,18 @@ def _cluster_ica(data, n_clusters=2, random_state=None, **kwargs):
 # SKLEARN
 # =============================================================================
 def _cluster_sklearn(data, method="spectral", n_clusters=2, **kwargs):
-    """Spectral clustering
-    """
+    """Spectral clustering"""
     # Initialize clustering function
     if method in ["spectral"]:
         clustering_model = sklearn.cluster.SpectralClustering(n_clusters=n_clusters, **kwargs)
     elif method in ["hierarchical", "ward"]:
-        clustering_model = sklearn.cluster.AgglomerativeClustering(n_clusters=n_clusters, linkage="ward", **kwargs)
+        clustering_model = sklearn.cluster.AgglomerativeClustering(
+            n_clusters=n_clusters, linkage="ward", **kwargs
+        )
     elif method in ["agglomerative", "single"]:
-        clustering_model = sklearn.cluster.AgglomerativeClustering(n_clusters=n_clusters, linkage="single", **kwargs)
+        clustering_model = sklearn.cluster.AgglomerativeClustering(
+            n_clusters=n_clusters, linkage="single", **kwargs
+        )
 
     # Fit
     clustering = clustering_model.fit_predict(data)
@@ -530,30 +565,29 @@ def _cluster_sklearn(data, method="spectral", n_clusters=2, **kwargs):
     prediction["Cluster"] = clustering
 
     # Else, copy function
-    clustering_function = functools.partial(_cluster_sklearn,
-                                            n_clusters=n_clusters,
-                                            **kwargs)
+    clustering_function = functools.partial(_cluster_sklearn, n_clusters=n_clusters, **kwargs)
 
     # Info dump
-    info = {"n_clusters": n_clusters,
-            "clustering_function": clustering_function,
-            "sklearn_model": clustering_model}
+    info = {
+        "n_clusters": n_clusters,
+        "clustering_function": clustering_function,
+        "sklearn_model": clustering_model,
+    }
 
     return prediction, clusters, info
 
 
 def _cluster_mixture(data, n_clusters=2, bayesian=False, random_state=None, **kwargs):
-    """Mixture model
-    """
+    """Mixture model"""
     # Initialize clustering function
     if bayesian is False:
-        clustering_model = sklearn.mixture.GaussianMixture(n_components=n_clusters,
-                                                           random_state=random_state,
-                                                           **kwargs)
+        clustering_model = sklearn.mixture.GaussianMixture(
+            n_components=n_clusters, random_state=random_state, **kwargs
+        )
     else:
-        clustering_model = sklearn.mixture.BayesianGaussianMixture(n_components=n_clusters,
-                                                                   random_state=random_state,
-                                                                   **kwargs)
+        clustering_model = sklearn.mixture.BayesianGaussianMixture(
+            n_components=n_clusters, random_state=random_state, **kwargs
+        )
 
     # Fit
     clustering = clustering_model.fit_predict(data)
@@ -567,25 +601,36 @@ def _cluster_mixture(data, n_clusters=2, bayesian=False, random_state=None, **kw
     prediction["Cluster"] = clustering
 
     # Else, copy function
-    clustering_function = functools.partial(_cluster_mixture,
-                                            n_clusters=n_clusters,
-                                            random_state=random_state,
-                                            **kwargs)
+    clustering_function = functools.partial(
+        _cluster_mixture, n_clusters=n_clusters, random_state=random_state, **kwargs
+    )
 
     # Info dump
-    info = {"n_clusters": n_clusters,
-            "clustering_function": clustering_function,
-            "sklearn_model": clustering_model,
-            "random_state": random_state}
+    info = {
+        "n_clusters": n_clusters,
+        "clustering_function": clustering_function,
+        "sklearn_model": clustering_model,
+        "random_state": random_state,
+    }
 
     return prediction, clusters, info
 
+
 # =============================================================================
 # AAHC
 # =============================================================================
 
 
-def _cluster_aahc(data, n_clusters=2, gfp=None, gfp_peaks=None, gfp_sum_sq=None, random_state=None, use_peaks=False, **kwargs):
+def _cluster_aahc(
+    data,
+    n_clusters=2,
+    gfp=None,
+    gfp_peaks=None,
+    gfp_sum_sq=None,
+    random_state=None,
+    use_peaks=False,
+    **kwargs
+):
     """Atomize and Agglomerative Hierarchical Clustering Algorithm, AAHC (Murray et al., Brain Topography, 2008),
     implemented by https://github.com/Frederic-vW/eeg_microstates/blob/master/eeg_microstates.py#L518
 
@@ -597,12 +642,12 @@ def _cluster_aahc(data, n_clusters=2, gfp=None, gfp_peaks=None, gfp_sum_sq=None,
     # Internal functions for aahc
     def extract_row(A, k):
         v = A[k, :]
-        A_ = np.vstack((A[:k, :], A[k+1:, :]))
+        A_ = np.vstack((A[:k, :], A[k + 1 :, :]))
         return A_, v
 
     def extract_item(A, k):
         a = A[k]
-        A_ = A[:k] + A[k+1:]
+        A_ = A[:k] + A[k + 1 :]
         return A_, a
 
     def locmax(x):
@@ -626,7 +671,7 @@ def _cluster_aahc(data, n_clusters=2, gfp=None, gfp_peaks=None, gfp_sum_sq=None,
     if gfp is None and gfp_peaks is None and gfp_sum_sq is None:
         gfp = data.std(axis=1)
         gfp_peaks = locmax(gfp)
-        gfp_sum_sq = np.sum(gfp**2)  # normalizing constant in GEV
+        gfp_sum_sq = np.sum(gfp ** 2)  # normalizing constant in GEV
         if use_peaks:
             maps = data[gfp_peaks, :]  # initialize clusters
             cluster_data = data[gfp_peaks, :]  # store original gfp peak indices
@@ -643,22 +688,22 @@ def _cluster_aahc(data, n_clusters=2, gfp=None, gfp_peaks=None, gfp_sum_sq=None,
     Ci = [[k] for k in range(n_maps)]
 
     # Main loop: atomize + agglomerate
-    while (n_maps > n_clusters):
+    while n_maps > n_clusters:
 
         # correlations of the data sequence with each cluster
         m_x, s_x = data.mean(axis=1, keepdims=True), data.std(axis=1)
         m_y, s_y = maps.mean(axis=1, keepdims=True), maps.std(axis=1)
-        s_xy = 1.*nch*np.outer(s_x, s_y)
-        C = np.dot(data-m_x, np.transpose(maps-m_y)) / s_xy
+        s_xy = 1.0 * nch * np.outer(s_x, s_y)
+        C = np.dot(data - m_x, np.transpose(maps - m_y)) / s_xy
 
         # microstate sequence, ignore polarity
-        L = np.argmax(C**2, axis=1)
+        L = np.argmax(C ** 2, axis=1)
 
         # GEV (global explained variance) of cluster k
         gev = np.zeros(n_maps)
         for k in range(n_maps):
             r = L == k
-            gev[k] = np.sum(gfp[r]**2 * C[r, k]**2)/gfp_sum_sq
+            gev[k] = np.sum(gfp[r] ** 2 * C[r, k] ** 2) / gfp_sum_sq
 
         # merge cluster with the minimum GEV
         imin = np.argmin(gev)
@@ -671,9 +716,9 @@ def _cluster_aahc(data, n_clusters=2, gfp=None, gfp_peaks=None, gfp_sum_sq=None,
             c = cluster_data[k, :]
             m_x, s_x = maps.mean(axis=1, keepdims=True), maps.std(axis=1)
             m_y, s_y = c.mean(), c.std()
-            s_xy = 1.*nch*s_x*s_y
-            C = np.dot(maps-m_x, c-m_y)/s_xy
-            inew = np.argmax(C**2)  # ignore polarity
+            s_xy = 1.0 * nch * s_x * s_y
+            C = np.dot(maps - m_x, c - m_y) / s_xy
+            inew = np.argmax(C ** 2)  # ignore polarity
             re_cluster.append(inew)
             Ci[inew].append(k)
         n_maps = len(Ci)
@@ -689,36 +734,38 @@ def _cluster_aahc(data, n_clusters=2, gfp=None, gfp_peaks=None, gfp_sum_sq=None,
             evals, evecs = np.linalg.eig(Sk)
             c = evecs[:, np.argmax(np.abs(evals))]
             c = np.real(c)
-            maps[i] = c/np.sqrt(np.sum(c**2))
+            maps[i] = c / np.sqrt(np.sum(c ** 2))
 
     # Get distance
     prediction = _cluster_quality_distance(cluster_data, maps, to_dataframe=True)
     prediction["Cluster"] = prediction.abs().idxmax(axis=1).values
-    prediction["Cluster"] = [np.where(prediction.columns == state)[0][0] for state in prediction["Cluster"]]
+    prediction["Cluster"] = [
+        np.where(prediction.columns == state)[0][0] for state in prediction["Cluster"]
+    ]
 
     # Function
-    clustering_function = functools.partial(_cluster_aahc,
-                                            n_clusters=n_clusters,
-                                            random_state=random_state,
-                                            **kwargs)
+    clustering_function = functools.partial(
+        _cluster_aahc, n_clusters=n_clusters, random_state=random_state, **kwargs
+    )
 
     # Info dump
-    info = {"n_clusters": n_clusters,
-            "clustering_function": clustering_function,
-            "random_state": random_state}
+    info = {
+        "n_clusters": n_clusters,
+        "clustering_function": clustering_function,
+        "random_state": random_state,
+    }
 
     return prediction, maps, info
 
 
-
 # =============================================================================
 # =============================================================================
 # # Utils
 # =============================================================================
 # =============================================================================
 
+
 def _cluster_getclusters(data, clustering):
-    """Get average representatives of clusters
-    """
+    """Get average representatives of clusters"""
     n_clusters = len(np.unique(clustering))
     return np.asarray([np.mean(data[np.where(clustering == i)], axis=0) for i in range(n_clusters)])
