@@ -1,12 +1,12 @@
+import antropy
 import nolds
 import numpy as np
 import pandas as pd
 from pyentrp import entropy as pyentrp
-import antropy
 
+# import EntropyHub
 import neurokit2 as nk
 
-
 """
 For the testing of complexity, we test our implementations against existing and established ones.
 However, some of these other implementations are not really packaged in a way
@@ -24,22 +24,22 @@ def test_complexity_sanity():
     mdfa_q = [-5, -3, -1, 1, 3, 5]
 
     # Entropy
-    assert np.allclose(nk.entropy_fuzzy(signal)[0], nk.entropy_sample(signal, fuzzy=True)[0], atol=0.000001)
+    assert np.allclose(
+        nk.entropy_fuzzy(signal)[0], nk.entropy_sample(signal, fuzzy=True)[0], atol=0.000001
+    )
 
     # Fractal
-    fractal_dfa, parameters = nk.fractal_dfa(signal, windows=np.array([4, 8, 12, 20]))
-    assert parameters['fluctuations'].shape == (4, 1)
+    fractal_dfa, parameters = nk.fractal_dfa(signal, scale=np.array([4, 8, 12, 20]))
+    assert parameters["Fluctuations"].shape == (4, 1)
     assert np.allclose(fractal_dfa, 2.10090484, atol=0.000001)
 
     fractal_mdfa, parameters = nk.fractal_dfa(signal, multifractal=True, q=mdfa_q)
-    assert parameters['fluctuations'].shape == (70, len(mdfa_q))
-    assert np.allclose(parameters["DimMean"], 0.6412650812085934, atol=0.000001)
-    assert np.allclose(parameters["DimRange"], 1.1105927013188868, atol=0.000001)
-    assert np.allclose(parameters["ExpMean"], 2.350615727142904, atol=0.000001)
-    assert np.allclose(parameters["ExpRange"], 0.9937858280904406, atol=0.000001)
+    assert parameters["Fluctuations"].shape == (70, len(mdfa_q))
 
-    assert np.allclose(nk.fractal_correlation(signal)[0], 0.7884473170763334, atol=0.000001)
-    assert np.allclose(nk.fractal_correlation(signal, radius="nolds")[0], nolds.corr_dim(signal, 2), atol=0.0001)
+    assert np.allclose(nk.fractal_correlation(signal)[0], 0.7930504156910694, atol=0.000001)
+    assert np.allclose(
+        nk.fractal_correlation(signal, radius="nolds")[0], nolds.corr_dim(signal, 2), atol=0.01
+    )
 
 
 # =============================================================================
@@ -93,13 +93,16 @@ def test_complexity_vs_R():
 
     # SampEn
     sampen = nk.entropy_sample(signal[0:300], dimension=2, tolerance=r)[0]
-    assert np.allclose(sampen, nk.entropy_sample(signal[0:300], dimension=2, tolerance=r, distance="infinity")[0], atol=0.001)
+    assert np.allclose(
+        sampen,
+        nk.entropy_sample(signal[0:300], dimension=2, tolerance=r, distance="infinity")[0],
+        atol=0.001,
+    )
     assert np.allclose(sampen, 0.03784376, atol=0.001)
     sampen = nk.entropy_sample(signal[0:300], dimension=3, delay=2, tolerance=r)[0]
     assert np.allclose(sampen, 0.09185509, atol=0.01)
 
 
-
 # =============================================================================
 # Comparison against Python implementations
 # =============================================================================
@@ -108,34 +111,59 @@ def test_complexity_vs_R():
 def test_complexity_vs_Python():
 
     signal = np.cos(np.linspace(start=0, stop=30, num=100))
+    tolerance = 0.2 * np.std(signal, ddof=1)
 
     # Shannon
     shannon = nk.entropy_shannon(signal)[0]
     #    assert scipy.stats.entropy(shannon, pd.Series(signal).value_counts())
-    assert np.allclose(shannon - pyentrp.shannon_entropy(signal), 0)
+    assert np.allclose(shannon, pyentrp.shannon_entropy(signal))
 
     # Approximate
     assert np.allclose(nk.entropy_approximate(signal)[0], 0.17364897858477146)
+
+    # EntropyHub doens't work because of PyEMD
+    # assert np.allclose(
+    #     nk.entropy_approximate(signal, dimension=2, tolerance=tolerance)[0],
+    #     EntropyHub.ApEn(signal, m=2, tau=1, r=tolerance)[0][2],
+    # )
     assert np.allclose(
-        nk.entropy_approximate(signal, dimension=2, tolerance=0.2 * np.std(signal, ddof=1))[0] - entropy_app_entropy(signal, 2), 0
+        nk.entropy_approximate(signal, dimension=2, tolerance=tolerance)[0],
+        entropy_app_entropy(signal, 2),
     )
 
-    assert nk.entropy_approximate(signal, dimension=2, tolerance=0.2 * np.std(signal, ddof=1))[0] != pyeeg_ap_entropy(
-        signal, 2, 0.2 * np.std(signal, ddof=1)
+    assert nk.entropy_approximate(signal, dimension=2, tolerance=tolerance)[0] != pyeeg_ap_entropy(
+        signal, 2, tolerance
     )
 
     # Sample
     assert np.allclose(
-        nk.entropy_sample(signal, dimension=2, tolerance=0.2 * np.std(signal, ddof=1))[0] - entropy_sample_entropy(signal, 2), 0
+        nk.entropy_sample(signal, dimension=2, tolerance=tolerance)[0],
+        entropy_sample_entropy(signal, 2),
     )
-    assert np.allclose(nk.entropy_sample(signal, dimension=2, tolerance=0.2)[0] - nolds.sampen(signal, 2, 0.2), 0)
-    assert np.allclose(nk.entropy_sample(signal, dimension=2, tolerance=0.2)[0] - entro_py_sampen(signal, 2, 0.2, scale=False), 0)
-    assert np.allclose(nk.entropy_sample(signal, dimension=2, tolerance=0.2)[0] - pyeeg_samp_entropy(signal, 2, 0.2), 0)
+    assert np.allclose(
+        nk.entropy_sample(signal, dimension=2, tolerance=0.2)[0],
+        nolds.sampen(signal, 2, 0.2),
+    )
+    assert np.allclose(
+        nk.entropy_sample(signal, dimension=2, tolerance=0.2)[0],
+        entro_py_sampen(signal, 2, 0.2, scale=False),
+    )
+    assert np.allclose(
+        nk.entropy_sample(signal, dimension=2, tolerance=0.2)[0],
+        pyeeg_samp_entropy(signal, 2, 0.2),
+    )
+    # assert np.allclose(
+    #     nk.entropy_sample(signal, dimension=2, tolerance=0.2)[0],
+    #     EntropyHub.SampEn(signal, m=2, tau=1, r=0.2)[0][2],
+    # )
 
     #    import sampen
     #    sampen.sampen2(signal[0:300], mm=2, r=r)
 
-    assert nk.entropy_sample(signal, dimension=2, tolerance=0.2)[0] != pyentrp.sample_entropy(signal, 2, 0.2)[1]
+    assert (
+        nk.entropy_sample(signal, dimension=2, tolerance=0.2)[0]
+        != pyentrp.sample_entropy(signal, 2, 0.2)[1]
+    )
     assert (
         nk.entropy_sample(signal, dimension=2, tolerance=0.2 * np.sqrt(np.var(signal)))[0]
         != MultiscaleEntropy_sample_entropy(signal, 2, 0.2)[0.2][2]
@@ -147,7 +175,9 @@ def test_complexity_vs_Python():
 
     # Fuzzy
     assert np.allclose(
-        nk.entropy_fuzzy(signal, dimension=2, tolerance=0.2, delay=1)[0] - entro_py_fuzzyen(signal, 2, 0.2, 1, scale=False), 0
+        nk.entropy_fuzzy(signal, dimension=2, tolerance=0.2, delay=1)[0]
+        - entro_py_fuzzyen(signal, 2, 0.2, 1, scale=False),
+        0,
     )
 
     # Lempel Ziv Complexity
@@ -155,13 +185,14 @@ def test_complexity_vs_Python():
     binary = np.zeros(len(signal))
     binary[signal > threshold] = 1
     assert np.allclose(
-        nk.complexity_lempelziv(signal, method="median", normalize=True)[0] - antropy.lziv_complexity(binary, normalize=True), 0
+        nk.complexity_lempelziv(signal, method="median", normalize=True)[0]
+        - antropy.lziv_complexity(binary, normalize=True),
+        0,
     )
 
     # Katz
-    assert np.allclose(
-        nk.fractal_katz(signal)[0] - antropy.katz_fd(signal), 0
-    )
+    assert np.allclose(nk.fractal_katz(signal)[0] - antropy.katz_fd(signal), 0)
+
 
 #    # DFA
 #    assert np.allclose(nk.fractal_dfa(signal, windows=np.array([4, 8, 12, 20]))['slopes'][0], nolds.dfa(
@@ -193,6 +224,7 @@ def wikipedia_sampen(signal, m=2, r=1):
     # Return SampEn
     return -np.log(A / B)
 
+
 # =============================================================================
 # entropy_estimators (https://github.com/paulbrodersen/entropy_estimators)
 # =============================================================================
@@ -233,7 +265,9 @@ def pyeeg_bin_power(X, Band, Fs):
     for Freq_Index in range(0, len(Band) - 1):
         Freq = float(Band[Freq_Index])
         Next_Freq = float(Band[Freq_Index + 1])
-        Power[Freq_Index] = sum(C[int(np.floor(Freq / Fs * len(X))) : int(np.floor(Next_Freq / Fs * len(X)))])
+        Power[Freq_Index] = sum(
+            C[int(np.floor(Freq / Fs * len(X))) : int(np.floor(Next_Freq / Fs * len(X)))]
+        )
     Power_Ratio = Power / sum(Power)
     return Power, Power_Ratio
 
@@ -309,7 +343,8 @@ def entropy_app_samp_entropy(x, order, metric="chebyshev", approximate=True):
     _all_metrics = KDTree.valid_metrics
     if metric not in _all_metrics:
         raise ValueError(
-            "The given metric (%s) is not valid. The valid " "metric names are: %s" % (metric, _all_metrics)
+            "The given metric (%s) is not valid. The valid "
+            "metric names are: %s" % (metric, _all_metrics)
         )
     phi = np.zeros(2)
     r = 0.2 * np.std(x, axis=-1, ddof=1)
@@ -320,10 +355,18 @@ def entropy_app_samp_entropy(x, order, metric="chebyshev", approximate=True):
         emb_data1 = _emb_data1
     else:
         emb_data1 = _emb_data1[:-1]
-    count1 = KDTree(emb_data1, metric=metric).query_radius(emb_data1, r, count_only=True).astype(np.float64)
+    count1 = (
+        KDTree(emb_data1, metric=metric)
+        .query_radius(emb_data1, r, count_only=True)
+        .astype(np.float64)
+    )
     # compute phi(order + 1, r)
     emb_data2 = entropy_embed(x, order + 1, 1)
-    count2 = KDTree(emb_data2, metric=metric).query_radius(emb_data2, r, count_only=True).astype(np.float64)
+    count2 = (
+        KDTree(emb_data2, metric=metric)
+        .query_radius(emb_data2, r, count_only=True)
+        .astype(np.float64)
+    )
     if approximate:
         phi[0] = np.mean(np.log(count1 / emb_data1.shape[0]))
         phi[1] = np.mean(np.log(count2 / emb_data2.shape[0]))
@@ -469,13 +512,21 @@ def MultiscaleEntropy_check_type(x, num_type, name):
     if isinstance(x, num_type):
         tmp = [x]
     elif not isinstance(x, Iterable):
-        raise ValueError(name + " should be a " + num_type.__name__ + " or an iterator of " + num_type.__name__)
+        raise ValueError(
+            name + " should be a " + num_type.__name__ + " or an iterator of " + num_type.__name__
+        )
     else:
         tmp = []
         for i in x:
             tmp.append(i)
             if not isinstance(i, num_type):
-                raise ValueError(name + " should be a " + num_type.__name__ + " or an iterator of " + num_type.__name__)
+                raise ValueError(
+                    name
+                    + " should be a "
+                    + num_type.__name__
+                    + " or an iterator of "
+                    + num_type.__name__
+                )
     return tmp
 
 
@@ -495,7 +546,9 @@ def MultiscaleEntropy_coarse_grain(x, scale_factor):
     return ans
 
 
-def MultiscaleEntropy_sample_entropy(x, m=[2], r=[0.15], sd=None, return_type="dict", safe_mode=False):
+def MultiscaleEntropy_sample_entropy(
+    x, m=[2], r=[0.15], sd=None, return_type="dict", safe_mode=False
+):
     """[Sample Entropy, the threshold will be r*sd]
 
     Arguments:
