@@ -55,26 +55,7 @@ def test_hrv():
 
     ecg_hrv = nk.hrv(peaks, sampling_rate=1000)
 
-    columns = ['HRV_RMSSD', 'HRV_MeanNN', 'HRV_SDNN', 'HRV_SDSD', 'HRV_CVNN',
-               'HRV_CVSD', 'HRV_MedianNN', 'HRV_MadNN', 'HRV_MCVNN', 'HRV_IQRNN',
-               'HRV_pNN50', 'HRV_pNN20', 'HRV_TINN', 'HRV_HTI', 'HRV_ULF',
-               'HRV_VLF', 'HRV_LF', 'HRV_HF', 'HRV_VHF', 'HRV_LFHF', 'HRV_LFn',
-               'HRV_HFn', 'HRV_LnHF', 'HRV_SD1', 'HRV_SD2', 'HRV_SD1SD2', 'HRV_S',
-               'HRV_CSI', 'HRV_CVI', 'HRV_CSI_Modified', 'HRV_PIP', 'HRV_IALS',
-               'HRV_PSS', 'HRV_PAS', 'HRV_GI', 'HRV_SI', 'HRV_AI', 'HRV_PI',
-               'HRV_C1d', 'HRV_C1a', 'HRV_SD1d',
-               'HRV_SD1a', 'HRV_C2d',
-               'HRV_C2a', 'HRV_SD2d', 'HRV_SD2a',
-               'HRV_Cd', 'HRV_Ca', 'HRV_SDNNd',
-               'HRV_SDNNa', 'HRV_ApEn', 'HRV_SampEn', 'HRV_MSE', 'HRV_CMSE',
-               'HRV_RCMSE', 'HRV_CD', 'HRV_DFA_alpha1', 'HRV_DFA_alpha1_ExpRange',
-               'HRV_DFA_alpha1_ExpMean', 'HRV_DFA_alpha1_DimRange',
-               'HRV_DFA_alpha1_DimMean', 'HRV_DFA_alpha2',
-               'HRV_DFA_alpha2_ExpRange', 'HRV_DFA_alpha2_ExpMean',
-               'HRV_DFA_alpha2_DimRange', 'HRV_DFA_alpha2_DimMean']
-
-    assert all(elem in np.array(ecg_hrv.columns.values, dtype=object) for elem
-               in columns)
+    assert np.isclose(ecg_hrv["HRV_RMSSD"].values[0], 3.526, atol=0.1)
 
 
 def test_hrv_rsa():
@@ -83,22 +64,18 @@ def test_hrv_rsa():
     rsp_signals, _ = nk.rsp_process(data["RSP"], sampling_rate=100)
 
     rsa_feature_columns = [
-      'RSA_P2T_Mean',
-      'RSA_P2T_Mean_log',
-      'RSA_P2T_SD',
-      'RSA_P2T_NoRSA',
-      'RSA_PorgesBohrer',
-      'RSA_Gates_Mean',
-      'RSA_Gates_Mean_log',
-      'RSA_Gates_SD'
-     ]
+        "RSA_P2T_Mean",
+        "RSA_P2T_Mean_log",
+        "RSA_P2T_SD",
+        "RSA_P2T_NoRSA",
+        "RSA_PorgesBohrer",
+        "RSA_Gates_Mean",
+        "RSA_Gates_Mean_log",
+        "RSA_Gates_SD",
+    ]
 
     rsa_features = nk.hrv_rsa(
-        ecg_signals,
-        rsp_signals,
-        rpeaks=info,
-        sampling_rate=100,
-        continuous=False
+        ecg_signals, rsp_signals, rpeaks=info, sampling_rate=100, continuous=False
     )
 
     assert all(key in rsa_feature_columns for key in rsa_features.keys())
@@ -107,7 +84,7 @@ def test_hrv_rsa():
     with pytest.warns(misc.NeuroKitWarning, match=r"RSP signal not found. For this.*"):
         nk.hrv_rsa(ecg_signals, rpeaks=info, sampling_rate=100, continuous=False)
 
-    with pytest.warns(misc.NeuroKitWarning, match=r"RSP signal not found. RSP signal.*"):
+    with pytest.warns(misc.NeuroKitWarning, match=r"RSP signal not found. For this time.*"):
         nk.hrv_rsa(ecg_signals, pd.DataFrame(), rpeaks=info, sampling_rate=100, continuous=False)
 
     # Test missing rsp onsets/centers
