@@ -26,5 +26,5 @@ def test_standardize():
 def test_fit_loess():
 
     signal = np.cos(np.linspace(start=0, stop=10, num=1000))
-    fit = nk.fit_loess(signal, alpha=0.75)
+    fit, _ = nk.fit_loess(signal, alpha=0.75)
     assert np.allclose(np.mean(signal - fit), -0.0201905899, atol=0.0001)
